# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2018/8/24 0024
__author__ = 'huohuo'
demo_xml = '''<?xml version="1.0" encoding="UTF-8" standalone="yes"?>

<?mso-application progid="Word.Document"?>
<pkg:package xmlns:pkg="http://schemas.microsoft.com/office/2006/xmlPackage">
    <pkg:part id="pkg_parts"></pkg:part>
    <pkg:part pkg:name="/word/theme/theme1.xml" pkg:contentType="application/vnd.openxmlformats-officedocument.theme+xml">
        <pkg:xmlData>
            <a:theme name="Office 主题​​" xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main">
                <a:themeElements>
                    <a:clrScheme name="Office">
                        <a:dk1>
                            <a:sysClr val="windowText" lastClr="000000"/>
                        </a:dk1>
                        <a:lt1>
                            <a:sysClr val="window" lastClr="FFFFFF"/>
                        </a:lt1>
                        <a:dk2>
                            <a:srgbClr val="1F497D"/>
                        </a:dk2>
                        <a:lt2>
                            <a:srgbClr val="EEECE1"/>
                        </a:lt2>
                        <a:accent1>
                            <a:srgbClr val="4F81BD"/>
                        </a:accent1>
                        <a:accent2>
                            <a:srgbClr val="C0504D"/>
                        </a:accent2>
                        <a:accent3>
                            <a:srgbClr val="9BBB59"/>
                        </a:accent3>
                        <a:accent4>
                            <a:srgbClr val="8064A2"/>
                        </a:accent4>
                        <a:accent5>
                            <a:srgbClr val="4BACC6"/>
                        </a:accent5>
                        <a:accent6>
                            <a:srgbClr val="F79646"/>
                        </a:accent6>
                        <a:hlink>
                            <a:srgbClr val="0000FF"/>
                        </a:hlink>
                        <a:folHlink>
                            <a:srgbClr val="800080"/>
                        </a:folHlink>
                    </a:clrScheme>
                    <a:fontScheme name="Office">
                        <a:majorFont>
                            <a:latin typeface="Cambria"/>
                            <a:ea typeface=""/>
                            <a:cs typeface=""/>
                            <a:font script="Jpan" typeface="ＭＳ Ｐゴシック"/>
                            <a:font script="Hang" typeface="맑은 고딕"/>
                            <a:font script="Hans" typeface="宋体"/>
                            <a:font script="Hant" typeface="新細明體"/>
                            <a:font script="Arab" typeface="Times New Roman"/>
                            <a:font script="Hebr" typeface="Times New Roman"/>
                            <a:font script="Thai" typeface="Tahoma"/>
                            <a:font script="Ethi" typeface="Nyala"/>
                            <a:font script="Beng" typeface="Vrinda"/>
                            <a:font script="Gujr" typeface="Shruti"/>
                            <a:font script="Khmr" typeface="MoolBoran"/>
                            <a:font script="Knda" typeface="Tunga"/>
                            <a:font script="Guru" typeface="Raavi"/>
                            <a:font script="Cans" typeface="Euphemia"/>
                            <a:font script="Cher" typeface="Plantagenet Cherokee"/>
                            <a:font script="Yiii" typeface="Microsoft Yi Baiti"/>
                            <a:font script="Tibt" typeface="Microsoft Himalaya"/>
                            <a:font script="Thaa" typeface="MV Boli"/>
                            <a:font script="Deva" typeface="Mangal"/>
                            <a:font script="Telu" typeface="Gautami"/>
                            <a:font script="Taml" typeface="Latha"/>
                            <a:font script="Syrc" typeface="Estrangelo Edessa"/>
                            <a:font script="Orya" typeface="Kalinga"/>
                            <a:font script="Mlym" typeface="Kartika"/>
                            <a:font script="Laoo" typeface="DokChampa"/>
                            <a:font script="Sinh" typeface="Iskoola Pota"/>
                            <a:font script="Mong" typeface="Mongolian Baiti"/>
                            <a:font script="Viet" typeface="Times New Roman"/>
                            <a:font script="Uigh" typeface="Microsoft Uighur"/>
                            <a:font script="Geor" typeface="Sylfaen"/>
                        </a:majorFont>
                        <a:minorFont>
                            <a:latin typeface="Calibri"/>
                            <a:ea typeface=""/>
                            <a:cs typeface=""/>
                            <a:font script="Jpan" typeface="ＭＳ Ｐゴシック"/>
                            <a:font script="Hang" typeface="맑은 고딕"/>
                            <a:font script="Hans" typeface="宋体"/>
                            <a:font script="Hant" typeface="新細明體"/>
                            <a:font script="Arab" typeface="Arial"/>
                            <a:font script="Hebr" typeface="Arial"/>
                            <a:font script="Thai" typeface="Tahoma"/>
                            <a:font script="Ethi" typeface="Nyala"/>
                            <a:font script="Beng" typeface="Vrinda"/>
                            <a:font script="Gujr" typeface="Shruti"/>
                            <a:font script="Khmr" typeface="DaunPenh"/>
                            <a:font script="Knda" typeface="Tunga"/>
                            <a:font script="Guru" typeface="Raavi"/>
                            <a:font script="Cans" typeface="Euphemia"/>
                            <a:font script="Cher" typeface="Plantagenet Cherokee"/>
                            <a:font script="Yiii" typeface="Microsoft Yi Baiti"/>
                            <a:font script="Tibt" typeface="Microsoft Himalaya"/>
                            <a:font script="Thaa" typeface="MV Boli"/>
                            <a:font script="Deva" typeface="Mangal"/>
                            <a:font script="Telu" typeface="Gautami"/>
                            <a:font script="Taml" typeface="Latha"/>
                            <a:font script="Syrc" typeface="Estrangelo Edessa"/>
                            <a:font script="Orya" typeface="Kalinga"/>
                            <a:font script="Mlym" typeface="Kartika"/>
                            <a:font script="Laoo" typeface="DokChampa"/>
                            <a:font script="Sinh" typeface="Iskoola Pota"/>
                            <a:font script="Mong" typeface="Mongolian Baiti"/>
                            <a:font script="Viet" typeface="Arial"/>
                            <a:font script="Uigh" typeface="Microsoft Uighur"/>
                            <a:font script="Geor" typeface="Sylfaen"/>
                        </a:minorFont>
                    </a:fontScheme>
                    <a:fmtScheme name="Office">
                        <a:fillStyleLst>
                            <a:solidFill>
                                <a:schemeClr val="phClr"/>
                            </a:solidFill>
                            <a:gradFill rotWithShape="1">
                                <a:gsLst>
                                    <a:gs pos="0">
                                        <a:schemeClr val="phClr">
                                            <a:tint val="50000"/>
                                            <a:satMod val="300000"/>
                                        </a:schemeClr>
                                    </a:gs>
                                    <a:gs pos="35000">
                                        <a:schemeClr val="phClr">
                                            <a:tint val="37000"/>
                                            <a:satMod val="300000"/>
                                        </a:schemeClr>
                                    </a:gs>
                                    <a:gs pos="100000">
                                        <a:schemeClr val="phClr">
                                            <a:tint val="15000"/>
                                            <a:satMod val="350000"/>
                                        </a:schemeClr>
                                    </a:gs>
                                </a:gsLst>
                                <a:lin ang="16200000" scaled="1"/>
                            </a:gradFill>
                            <a:gradFill rotWithShape="1">
                                <a:gsLst>
                                    <a:gs pos="0">
                                        <a:schemeClr val="phClr">
                                            <a:shade val="51000"/>
                                            <a:satMod val="130000"/>
                                        </a:schemeClr>
                                    </a:gs>
                                    <a:gs pos="80000">
                                        <a:schemeClr val="phClr">
                                            <a:shade val="93000"/>
                                            <a:satMod val="130000"/>
                                        </a:schemeClr>
                                    </a:gs>
                                    <a:gs pos="100000">
                                        <a:schemeClr val="phClr">
                                            <a:shade val="94000"/>
                                            <a:satMod val="135000"/>
                                        </a:schemeClr>
                                    </a:gs>
                                </a:gsLst>
                                <a:lin ang="16200000" scaled="0"/>
                            </a:gradFill>
                        </a:fillStyleLst>
                        <a:lnStyleLst>
                            <a:ln w="9525" cap="flat" cmpd="sng" algn="ctr">
                                <a:solidFill>
                                    <a:schemeClr val="phClr">
                                        <a:shade val="95000"/>
                                        <a:satMod val="105000"/>
                                    </a:schemeClr>
                                </a:solidFill>
                                <a:prstDash val="solid"/>
                            </a:ln>
                            <a:ln w="25400" cap="flat" cmpd="sng" algn="ctr">
                                <a:solidFill>
                                    <a:schemeClr val="phClr"/>
                                </a:solidFill>
                                <a:prstDash val="solid"/>
                            </a:ln>
                            <a:ln w="38100" cap="flat" cmpd="sng" algn="ctr">
                                <a:solidFill>
                                    <a:schemeClr val="phClr"/>
                                </a:solidFill>
                                <a:prstDash val="solid"/>
                            </a:ln>
                        </a:lnStyleLst>
                        <a:effectStyleLst>
                            <a:effectStyle>
                                <a:effectLst>
                                    <a:outerShdw blurRad="40000" dist="20000" dir="5400000" rotWithShape="0">
                                        <a:srgbClr val="000000">
                                            <a:alpha val="38000"/>
                                        </a:srgbClr>
                                    </a:outerShdw>
                                </a:effectLst>
                            </a:effectStyle>
                            <a:effectStyle>
                                <a:effectLst>
                                    <a:outerShdw blurRad="40000" dist="23000" dir="5400000" rotWithShape="0">
                                        <a:srgbClr val="000000">
                                            <a:alpha val="35000"/>
                                        </a:srgbClr>
                                    </a:outerShdw>
                                </a:effectLst>
                            </a:effectStyle>
                            <a:effectStyle>
                                <a:effectLst>
                                    <a:outerShdw blurRad="40000" dist="23000" dir="5400000" rotWithShape="0">
                                        <a:srgbClr val="000000">
                                            <a:alpha val="35000"/>
                                        </a:srgbClr>
                                    </a:outerShdw>
                                </a:effectLst>
                                <a:scene3d>
                                    <a:camera prst="orthographicFront">
                                        <a:rot lat="0" lon="0" rev="0"/>
                                    </a:camera>
                                    <a:lightRig rig="threePt" dir="t">
                                        <a:rot lat="0" lon="0" rev="1200000"/>
                                    </a:lightRig>
                                </a:scene3d>
                                <a:sp3d>
                                    <a:bevelT w="63500" h="25400"/>
                                </a:sp3d>
                            </a:effectStyle>
                        </a:effectStyleLst>
                        <a:bgFillStyleLst>
                            <a:solidFill>
                                <a:schemeClr val="phClr"/>
                            </a:solidFill>
                            <a:gradFill rotWithShape="1">
                                <a:gsLst>
                                    <a:gs pos="0">
                                        <a:schemeClr val="phClr">
                                            <a:tint val="40000"/>
                                            <a:satMod val="350000"/>
                                        </a:schemeClr>
                                    </a:gs>
                                    <a:gs pos="40000">
                                        <a:schemeClr val="phClr">
                                            <a:tint val="45000"/>
                                            <a:satMod val="350000"/>
                                            <a:shade val="99000"/>
                                        </a:schemeClr>
                                    </a:gs>
                                    <a:gs pos="100000">
                                        <a:schemeClr val="phClr">
                                            <a:shade val="20000"/>
                                            <a:satMod val="255000"/>
                                        </a:schemeClr>
                                    </a:gs>
                                </a:gsLst>
                                <a:path path="circle">
                                    <a:fillToRect l="50000" t="-80000" r="50000" b="180000"/>
                                </a:path>
                            </a:gradFill>
                            <a:gradFill rotWithShape="1">
                                <a:gsLst>
                                    <a:gs pos="0">
                                        <a:schemeClr val="phClr">
                                            <a:tint val="80000"/>
                                            <a:satMod val="300000"/>
                                        </a:schemeClr>
                                    </a:gs>
                                    <a:gs pos="100000">
                                        <a:schemeClr val="phClr">
                                            <a:shade val="30000"/>
                                            <a:satMod val="200000"/>
                                        </a:schemeClr>
                                    </a:gs>
                                </a:gsLst>
                                <a:path path="circle">
                                    <a:fillToRect l="50000" t="50000" r="50000" b="50000"/>
                                </a:path>
                            </a:gradFill>
                        </a:bgFillStyleLst>
                    </a:fmtScheme>
                </a:themeElements>
                <a:objectDefaults/>
                <a:extraClrSchemeLst/>
            </a:theme>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/word/settings.xml" pkg:contentType="application/vnd.openxmlformats-officedocument.wordprocessingml.settings+xml">
        <pkg:xmlData>
            <w:settings mc:Ignorable="w14" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" xmlns:o="urn:schemas-microsoft-com:office:office" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math" xmlns:v="urn:schemas-microsoft-com:vml" xmlns:w10="urn:schemas-microsoft-com:office:word" xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main" xmlns:w14="http://schemas.microsoft.com/office/word/2010/wordml" xmlns:sl="http://schemas.openxmlformats.org/schemaLibrary/2006/main">
                <w:zoom w:percent="100"/>
                <w:bordersDoNotSurroundHeader/>
                <w:bordersDoNotSurroundFooter/>
                <w:defaultTabStop w:val="420"/>
                <w:drawingGridHorizontalSpacing w:val="105"/>
                <w:drawingGridVerticalSpacing w:val="156"/>
                <w:displayHorizontalDrawingGridEvery w:val="0"/>
                <w:displayVerticalDrawingGridEvery w:val="2"/>
                <w:characterSpacingControl w:val="compressPunctuation"/>
                <w:noLineBreaksAfter w:lang="zh-CN" w:val="$([{£¥·‘“〈《「『【〔〖〝﹙﹛﹝＄（．［｛￡￥"/>
                <w:noLineBreaksBefore w:lang="zh-CN" w:val="!%),.:;&gt;?]}¢¨°·ˇˉ―‖’”…‰′″›℃∶、。〃〉》」』】〕〗〞︶︺︾﹀﹄﹚﹜﹞！＂％＇），．：；？］｀｜｝～￠"/>
                <w:hdrShapeDefaults>
                    <o:shapedefaults v:ext="edit" spidmax="2049" strokecolor="#739cc3">
                        <v:fill angle="90" type="gradient">
                            <o:fill v:ext="view" type="gradientUnscaled"/>
                        </v:fill>
                        <v:stroke color="#739cc3" weight="1.25pt"/>
                    </o:shapedefaults>
                </w:hdrShapeDefaults>
                <w:footnotePr>
                    <w:footnote w:id="-1"/>
                    <w:footnote w:id="0"/>
                </w:footnotePr>
                <w:endnotePr>
                    <w:endnote w:id="-1"/>
                    <w:endnote w:id="0"/>
                </w:endnotePr>
                <w:compat>
                    <w:spaceForUL/>
                    <w:balanceSingleByteDoubleByteWidth/>
                    <w:doNotLeaveBackslashAlone/>
                    <w:ulTrailSpace/>
                    <w:doNotExpandShiftReturn/>
                    <w:adjustLineHeightInTable/>
                    <w:useFELayout/>
                    <w:compatSetting w:name="compatibilityMode" w:uri="http://schemas.microsoft.com/office/word" w:val="14"/>
                    <w:compatSetting w:name="overrideTableStyleFontSizeAndJustification" w:uri="http://schemas.microsoft.com/office/word" w:val="1"/>
                    <w:compatSetting w:name="enableOpenTypeFeatures" w:uri="http://schemas.microsoft.com/office/word" w:val="1"/>
                    <w:compatSetting w:name="doNotFlipMirrorIndents" w:uri="http://schemas.microsoft.com/office/word" w:val="1"/>
                </w:compat>
                <w:rsids>
                    <w:rsidRoot w:val="00A61739"/>
                    <w:rsid w:val="0001188F"/>
                    <w:rsid w:val="00020C24"/>
                    <w:rsid w:val="00030917"/>
                    <w:rsid w:val="00034317"/>
                    <w:rsid w:val="00061BEB"/>
                    <w:rsid w:val="00085FFD"/>
                    <w:rsid w:val="00093F30"/>
                    <w:rsid w:val="000C7108"/>
                    <w:rsid w:val="00183C82"/>
                    <w:rsid w:val="001923FD"/>
                    <w:rsid w:val="0020116C"/>
                    <w:rsid w:val="0020447A"/>
                    <w:rsid w:val="00260027"/>
                    <w:rsid w:val="00277F64"/>
                    <w:rsid w:val="002829A7"/>
                    <w:rsid w:val="00284BF2"/>
                    <w:rsid w:val="002E7D33"/>
                    <w:rsid w:val="003007A3"/>
                    <w:rsid w:val="00326FD6"/>
                    <w:rsid w:val="00336B95"/>
                    <w:rsid w:val="0035090B"/>
                    <w:rsid w:val="00353074"/>
                    <w:rsid w:val="003717F2"/>
                    <w:rsid w:val="00392D66"/>
                    <w:rsid w:val="00397A2F"/>
                    <w:rsid w:val="00402F16"/>
                    <w:rsid w:val="00433CE3"/>
                    <w:rsid w:val="00475355"/>
                    <w:rsid w:val="0049272C"/>
                    <w:rsid w:val="00497F79"/>
                    <w:rsid w:val="004B11D9"/>
                    <w:rsid w:val="004B719F"/>
                    <w:rsid w:val="004F300D"/>
                    <w:rsid w:val="0050637B"/>
                    <w:rsid w:val="00512ED0"/>
                    <w:rsid w:val="00594E10"/>
                    <w:rsid w:val="00595491"/>
                    <w:rsid w:val="005D6A2D"/>
                    <w:rsid w:val="00611E52"/>
                    <w:rsid w:val="006537A4"/>
                    <w:rsid w:val="00670356"/>
                    <w:rsid w:val="006736B0"/>
                    <w:rsid w:val="0070728B"/>
                    <w:rsid w:val="00814EEF"/>
                    <w:rsid w:val="00834713"/>
                    <w:rsid w:val="008556E3"/>
                    <w:rsid w:val="00873475"/>
                    <w:rsid w:val="008D0C9C"/>
                    <w:rsid w:val="0093050B"/>
                    <w:rsid w:val="0094017E"/>
                    <w:rsid w:val="00975702"/>
                    <w:rsid w:val="00993829"/>
                    <w:rsid w:val="009D6104"/>
                    <w:rsid w:val="009E78F0"/>
                    <w:rsid w:val="00A32E6F"/>
                    <w:rsid w:val="00A4408A"/>
                    <w:rsid w:val="00A608FB"/>
                    <w:rsid w:val="00A61739"/>
                    <w:rsid w:val="00A80E81"/>
                    <w:rsid w:val="00A8491C"/>
                    <w:rsid w:val="00A91445"/>
                    <w:rsid w:val="00AC3F4B"/>
                    <w:rsid w:val="00B56A1E"/>
                    <w:rsid w:val="00B62584"/>
                    <w:rsid w:val="00BA1CD3"/>
                    <w:rsid w:val="00C01E42"/>
                    <w:rsid w:val="00C03ED7"/>
                    <w:rsid w:val="00C83B17"/>
                    <w:rsid w:val="00CB4AFE"/>
                    <w:rsid w:val="00CF75A9"/>
                    <w:rsid w:val="00D614D4"/>
                    <w:rsid w:val="00DA600A"/>
                    <w:rsid w:val="00DA6872"/>
                    <w:rsid w:val="00E00100"/>
                    <w:rsid w:val="00E02B62"/>
                    <w:rsid w:val="00E61A64"/>
                    <w:rsid w:val="00E74174"/>
                    <w:rsid w:val="00E745F3"/>
                    <w:rsid w:val="00EA277F"/>
                    <w:rsid w:val="00EC6AF9"/>
                    <w:rsid w:val="00EE7753"/>
                    <w:rsid w:val="00FA5113"/>
                    <w:rsid w:val="5C661866"/>
                </w:rsids>
                <m:mathPr>
                    <m:mathFont m:val="Cambria Math"/>
                    <m:brkBin m:val="before"/>
                    <m:brkBinSub m:val="--"/>
                    <m:smallFrac/>
                    <m:dispDef/>
                    <m:lMargin m:val="0"/>
                    <m:rMargin m:val="0"/>
                    <m:defJc m:val="centerGroup"/>
                    <m:wrapIndent m:val="1440"/>
                    <m:intLim m:val="subSup"/>
                    <m:naryLim m:val="undOvr"/>
                </m:mathPr>
                <w:themeFontLang w:val="en-US" w:eastAsia="zh-CN"/>
                <w:clrSchemeMapping w:bg1="light1" w:t1="dark1" w:bg2="light2" w:t2="dark2" w:accent1="accent1" w:accent2="accent2" w:accent3="accent3" w:accent4="accent4" w:accent5="accent5" w:accent6="accent6" w:hyperlink="hyperlink" w:followedHyperlink="followedHyperlink"/>
                <w:shapeDefaults>
                    <o:shapedefaults v:ext="edit" spidmax="2049" strokecolor="#739cc3">
                        <v:fill angle="90" type="gradient">
                            <o:fill v:ext="view" type="gradientUnscaled"/>
                        </v:fill>
                        <v:stroke color="#739cc3" weight="1.25pt"/>
                    </o:shapedefaults>
                    <o:shapelayout v:ext="edit">
                        <o:idmap v:ext="edit" data="1"/>
                    </o:shapelayout>
                </w:shapeDefaults>
                <w:decimalSymbol w:val="."/>
                <w:listSeparator w:val=","/>
            </w:settings>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/customXml/itemProps2.xml" pkg:contentType="application/vnd.openxmlformats-officedocument.customXmlProperties+xml" pkg:padding="32">
        <pkg:xmlData pkg:originalXmlStandalone="no">
            <ds:datastoreItem ds:itemID="{EB4C5D3F-560E-4423-A1D3-9D305D9A6F92}" xmlns:ds="http://schemas.openxmlformats.org/officeDocument/2006/customXml">
                <ds:schemaRefs>
                    <ds:schemaRef ds:uri="http://schemas.openxmlformats.org/officeDocument/2006/bibliography"/>
                </ds:schemaRefs>
            </ds:datastoreItem>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/docProps/custom.xml" pkg:contentType="application/vnd.openxmlformats-officedocument.custom-properties+xml" pkg:padding="256">
        <pkg:xmlData>
            <Properties xmlns="http://schemas.openxmlformats.org/officeDocument/2006/custom-properties" xmlns:vt="http://schemas.openxmlformats.org/officeDocument/2006/docPropsVTypes">
                <property fmtid="{D5CDD505-2E9C-101B-9397-08002B2CF9AE}" pid="2" name="KSOProductBuildVer">
                    <vt:lpwstr>2052-10.1.0.6029</vt:lpwstr>
                </property>
            </Properties>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/docProps/app.xml" pkg:contentType="application/vnd.openxmlformats-officedocument.extended-properties+xml" pkg:padding="256">
        <pkg:xmlData>
            <Properties xmlns="http://schemas.openxmlformats.org/officeDocument/2006/extended-properties" xmlns:vt="http://schemas.openxmlformats.org/officeDocument/2006/docPropsVTypes">
                <Template>Normal.dotm</Template>
                <TotalTime>0</TotalTime>
                <Pages>4</Pages>
                <Words>1606</Words>
                <Characters>9157</Characters>
                <Application>Microsoft Office Word</Application>
                <DocSecurity>0</DocSecurity>
                <Lines>76</Lines>
                <Paragraphs>21</Paragraphs>
                <ScaleCrop>false</ScaleCrop>
                <Company>Sky123.Org</Company>
                <LinksUpToDate>false</LinksUpToDate>
                <CharactersWithSpaces>10742</CharactersWithSpaces>
                <SharedDoc>false</SharedDoc>
                <HyperlinksChanged>false</HyperlinksChanged>
                <AppVersion>14.0000</AppVersion>
            </Properties>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/customXml/itemProps1.xml" pkg:contentType="application/vnd.openxmlformats-officedocument.customXmlProperties+xml" pkg:padding="32">
        <pkg:xmlData pkg:originalXmlStandalone="no">
            <ds:datastoreItem ds:itemID="{B1977F7D-205B-4081-913C-38D41E755F92}" xmlns:ds="http://schemas.openxmlformats.org/officeDocument/2006/customXml">
                <ds:schemaRefs>
                    <ds:schemaRef ds:uri="http://www.wps.cn/officeDocument/2013/wpsCustomData"/>
                </ds:schemaRefs>
            </ds:datastoreItem>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/customXml/_rels/item1.xml.rels" pkg:contentType="application/vnd.openxmlformats-package.relationships+xml" pkg:padding="256">
        <pkg:xmlData>
            <Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships">
                <Relationship Id="rId1" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/customXmlProps" Target="itemProps1.xml"/>
            </Relationships>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/customXml/_rels/item2.xml.rels" pkg:contentType="application/vnd.openxmlformats-package.relationships+xml" pkg:padding="256">
        <pkg:xmlData>
            <Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships">
                <Relationship Id="rId1" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/customXmlProps" Target="itemProps2.xml"/>
            </Relationships>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/customXml/item2.xml" pkg:contentType="application/xml" pkg:padding="32">
        <pkg:xmlData>
            <b:Sources SelectedStyle="\APA.XSL" StyleName="APA" xmlns:b="http://schemas.openxmlformats.org/officeDocument/2006/bibliography" xmlns="http://schemas.openxmlformats.org/officeDocument/2006/bibliography"/>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/customXml/item1.xml" pkg:contentType="application/xml" pkg:padding="32">
        <pkg:xmlData>
            <s:customData xmlns="http://www.wps.cn/officeDocument/2013/wpsCustomData" xmlns:s="http://www.wps.cn/officeDocument/2013/wpsCustomData">
                <customSectProps>
                    <customSectPr/>
                    <customSectPr/>
                    <customSectPr/>
                    <customSectPr/>
                    <customSectPr/>
                </customSectProps>
                <customShpExts>
                    <customShpInfo spid="_x0000_s1026" textRotate="1"/>
                </customShpExts>
            </s:customData>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/word/fontTable.xml" pkg:contentType="application/vnd.openxmlformats-officedocument.wordprocessingml.fontTable+xml">
        <pkg:xmlData>
            <w:fonts mc:Ignorable="w14" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main" xmlns:w14="http://schemas.microsoft.com/office/word/2010/wordml">
                <w:font w:name="Symbol">
                    <w:panose1 w:val="05050102010706020507"/>
                    <w:charset w:val="02"/>
                    <w:family w:val="roman"/>
                    <w:pitch w:val="variable"/>
                    <w:sig w:usb0="00000000" w:usb1="10000000" w:usb2="00000000" w:usb3="00000000" w:csb0="80000000" w:csb1="00000000"/>
                </w:font>
                <w:font w:name="Times New Roman">
                    <w:panose1 w:val="02020603050405020304"/>
                    <w:charset w:val="00"/>
                    <w:family w:val="roman"/>
                    <w:pitch w:val="variable"/>
                    <w:sig w:usb0="E0002EFF" w:usb1="C000785B" w:usb2="00000009" w:usb3="00000000" w:csb0="000001FF" w:csb1="00000000"/>
                </w:font>
                <w:font w:name="宋体">
                    <w:altName w:val="SimSun"/>
                    <w:panose1 w:val="02010600030101010101"/>
                    <w:charset w:val="86"/>
                    <w:family w:val="auto"/>
                    <w:pitch w:val="variable"/>
                    <w:sig w:usb0="00000003" w:usb1="288F0000" w:usb2="00000016" w:usb3="00000000" w:csb0="00040001" w:csb1="00000000"/>
                </w:font>
                <w:font w:name="黑体">
                    <w:altName w:val="SimHei"/>
                    <w:panose1 w:val="02010609060101010101"/>
                    <w:charset w:val="86"/>
                    <w:family w:val="modern"/>
                    <w:pitch w:val="fixed"/>
                    <w:sig w:usb0="800002BF" w:usb1="38CF7CFA" w:usb2="00000016" w:usb3="00000000" w:csb0="00040001" w:csb1="00000000"/>
                </w:font>
                <w:font w:name="Arial">
                    <w:panose1 w:val="020B0604020202020204"/>
                    <w:charset w:val="00"/>
                    <w:family w:val="swiss"/>
                    <w:pitch w:val="variable"/>
                    <w:sig w:usb0="E0002EFF" w:usb1="C0007843" w:usb2="00000009" w:usb3="00000000" w:csb0="000001FF" w:csb1="00000000"/>
                </w:font>
                <w:font w:name="Tahoma">
                    <w:panose1 w:val="020B0604030504040204"/>
                    <w:charset w:val="00"/>
                    <w:family w:val="swiss"/>
                    <w:pitch w:val="variable"/>
                    <w:sig w:usb0="E1002EFF" w:usb1="C000605B" w:usb2="00000029" w:usb3="00000000" w:csb0="000101FF" w:csb1="00000000"/>
                </w:font>
                <w:font w:name="Cambria">
                    <w:panose1 w:val="02040503050406030204"/>
                    <w:charset w:val="00"/>
                    <w:family w:val="roman"/>
                    <w:pitch w:val="variable"/>
                    <w:sig w:usb0="E00002FF" w:usb1="400004FF" w:usb2="00000000" w:usb3="00000000" w:csb0="0000019F" w:csb1="00000000"/>
                </w:font>
                <w:font w:name="Calibri">
                    <w:panose1 w:val="020F0502020204030204"/>
                    <w:charset w:val="00"/>
                    <w:family w:val="swiss"/>
                    <w:pitch w:val="variable"/>
                    <w:sig w:usb0="E0002AFF" w:usb1="C000247B" w:usb2="00000009" w:usb3="00000000" w:csb0="000001FF" w:csb1="00000000"/>
                </w:font>
                <w:font w:name="Courier">
                    <w:panose1 w:val="02070409020205020404"/>
                    <w:charset w:val="00"/>
                    <w:family w:val="modern"/>
                    <w:notTrueType/>
                    <w:pitch w:val="fixed"/>
                    <w:sig w:usb0="00000003" w:usb1="00000000" w:usb2="00000000" w:usb3="00000000" w:csb0="00000001" w:csb1="00000000"/>
                </w:font>
                <w:font w:name="仿宋_GB2312">
                    <w:altName w:val="仿宋"/>
                    <w:charset w:val="86"/>
                    <w:family w:val="modern"/>
                    <w:pitch w:val="fixed"/>
                    <w:sig w:usb0="00000001" w:usb1="080E0000" w:usb2="00000010" w:usb3="00000000" w:csb0="00040000" w:csb1="00000000"/>
                </w:font>
                <w:font w:name="Verdana">
                    <w:panose1 w:val="020B0604030504040204"/>
                    <w:charset w:val="00"/>
                    <w:family w:val="swiss"/>
                    <w:pitch w:val="variable"/>
                    <w:sig w:usb0="A10006FF" w:usb1="4000205B" w:usb2="00000010" w:usb3="00000000" w:csb0="0000019F" w:csb1="00000000"/>
                </w:font>
                <w:font w:name="Adobe 宋体 Std L">
                    <w:altName w:val="宋体"/>
                    <w:charset w:val="86"/>
                    <w:family w:val="roman"/>
                    <w:pitch w:val="default"/>
                    <w:sig w:usb0="00000000" w:usb1="00000000" w:usb2="00000016" w:usb3="00000000" w:csb0="00060007" w:csb1="00000000"/>
                </w:font>
                <w:font w:name="楷体">
                    <w:panose1 w:val="02010609060101010101"/>
                    <w:charset w:val="86"/>
                    <w:family w:val="modern"/>
                    <w:pitch w:val="fixed"/>
                    <w:sig w:usb0="800002BF" w:usb1="38CF7CFA" w:usb2="00000016" w:usb3="00000000" w:csb0="00040001" w:csb1="00000000"/>
                </w:font>
                <w:font w:name="微软雅黑">
                    <w:panose1 w:val="020B0503020204020204"/>
                    <w:charset w:val="86"/>
                    <w:family w:val="swiss"/>
                    <w:pitch w:val="variable"/>
                    <w:sig w:usb0="80000287" w:usb1="28CF3C50" w:usb2="00000016" w:usb3="00000000" w:csb0="0004001F" w:csb1="00000000"/>
                </w:font>
            </w:fonts>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/word/numbering.xml" pkg:contentType="application/vnd.openxmlformats-officedocument.wordprocessingml.numbering+xml">
        <pkg:xmlData>
            <w:numbering mc:Ignorable="w14 wp14" xmlns:wpc="http://schemas.microsoft.com/office/word/2010/wordprocessingCanvas" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" xmlns:o="urn:schemas-microsoft-com:office:office" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math" xmlns:v="urn:schemas-microsoft-com:vml" xmlns:wp14="http://schemas.microsoft.com/office/word/2010/wordprocessingDrawing" xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing" xmlns:w10="urn:schemas-microsoft-com:office:word" xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main" xmlns:w14="http://schemas.microsoft.com/office/word/2010/wordml" xmlns:wpg="http://schemas.microsoft.com/office/word/2010/wordprocessingGroup" xmlns:wpi="http://schemas.microsoft.com/office/word/2010/wordprocessingInk" xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml" xmlns:wps="http://schemas.microsoft.com/office/word/2010/wordprocessingShape">
                <w:abstractNum w:abstractNumId="0">
                    <w:nsid w:val="FFFFFF7E"/>
                    <w:multiLevelType w:val="singleLevel"/>
                    <w:tmpl w:val="FFFFFF7E"/>
                    <w:lvl w:ilvl="0">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="decimal"/>
                        <w:pStyle w:val="3"/>
                        <w:lvlText w:val="%1."/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:tabs>
                                <w:tab w:val="left" w:pos="1080"/>
                            </w:tabs>
                            <w:ind w:left="1080" w:hanging="360"/>
                        </w:pPr>
                    </w:lvl>
                </w:abstractNum>
                <w:abstractNum w:abstractNumId="1">
                    <w:nsid w:val="FFFFFF7F"/>
                    <w:multiLevelType w:val="singleLevel"/>
                    <w:tmpl w:val="FFFFFF7F"/>
                    <w:lvl w:ilvl="0">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="decimal"/>
                        <w:pStyle w:val="2"/>
                        <w:lvlText w:val="%1."/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:tabs>
                                <w:tab w:val="left" w:pos="720"/>
                            </w:tabs>
                            <w:ind w:left="720" w:hanging="360"/>
                        </w:pPr>
                    </w:lvl>
                </w:abstractNum>
                <w:abstractNum w:abstractNumId="2">
                    <w:nsid w:val="FFFFFF82"/>
                    <w:multiLevelType w:val="singleLevel"/>
                    <w:tmpl w:val="FFFFFF82"/>
                    <w:lvl w:ilvl="0">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="bullet"/>
                        <w:pStyle w:val="30"/>
                        <w:lvlText w:val=""/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:tabs>
                                <w:tab w:val="left" w:pos="1080"/>
                            </w:tabs>
                            <w:ind w:left="1080" w:hanging="360"/>
                        </w:pPr>
                        <w:rPr>
                            <w:rFonts w:ascii="Symbol" w:hAnsi="Symbol" w:hint="default"/>
                        </w:rPr>
                    </w:lvl>
                </w:abstractNum>
                <w:abstractNum w:abstractNumId="3">
                    <w:nsid w:val="FFFFFF83"/>
                    <w:multiLevelType w:val="singleLevel"/>
                    <w:tmpl w:val="FFFFFF83"/>
                    <w:lvl w:ilvl="0">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="bullet"/>
                        <w:pStyle w:val="20"/>
                        <w:lvlText w:val=""/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:tabs>
                                <w:tab w:val="left" w:pos="720"/>
                            </w:tabs>
                            <w:ind w:left="720" w:hanging="360"/>
                        </w:pPr>
                        <w:rPr>
                            <w:rFonts w:ascii="Symbol" w:hAnsi="Symbol" w:hint="default"/>
                        </w:rPr>
                    </w:lvl>
                </w:abstractNum>
                <w:abstractNum w:abstractNumId="4">
                    <w:nsid w:val="FFFFFF88"/>
                    <w:multiLevelType w:val="singleLevel"/>
                    <w:tmpl w:val="FFFFFF88"/>
                    <w:lvl w:ilvl="0">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="decimal"/>
                        <w:pStyle w:val="a"/>
                        <w:lvlText w:val="%1."/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:tabs>
                                <w:tab w:val="left" w:pos="360"/>
                            </w:tabs>
                            <w:ind w:left="360" w:hanging="360"/>
                        </w:pPr>
                    </w:lvl>
                </w:abstractNum>
                <w:abstractNum w:abstractNumId="5">
                    <w:nsid w:val="FFFFFF89"/>
                    <w:multiLevelType w:val="singleLevel"/>
                    <w:tmpl w:val="FFFFFF89"/>
                    <w:lvl w:ilvl="0">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="bullet"/>
                        <w:pStyle w:val="a0"/>
                        <w:lvlText w:val=""/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:tabs>
                                <w:tab w:val="left" w:pos="360"/>
                            </w:tabs>
                            <w:ind w:left="360" w:hanging="360"/>
                        </w:pPr>
                        <w:rPr>
                            <w:rFonts w:ascii="Symbol" w:hAnsi="Symbol" w:hint="default"/>
                        </w:rPr>
                    </w:lvl>
                </w:abstractNum>
                <w:abstractNum w:abstractNumId="6">
                    <w:nsid w:val="419E14A3"/>
                    <w:multiLevelType w:val="multilevel"/>
                    <w:tmpl w:val="419E14A3"/>
                    <w:lvl w:ilvl="0">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="decimal"/>
                        <w:lvlText w:val="%1、"/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="360" w:hanging="360"/>
                        </w:pPr>
                        <w:rPr>
                            <w:rFonts w:hint="default"/>
                        </w:rPr>
                    </w:lvl>
                    <w:lvl w:ilvl="1">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerLetter"/>
                        <w:lvlText w:val="%2)"/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="840" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="2">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerRoman"/>
                        <w:lvlText w:val="%3."/>
                        <w:lvlJc w:val="right"/>
                        <w:pPr>
                            <w:ind w:left="1260" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="3">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="decimal"/>
                        <w:lvlText w:val="%4."/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="1680" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="4">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerLetter"/>
                        <w:lvlText w:val="%5)"/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="2100" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="5">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerRoman"/>
                        <w:lvlText w:val="%6."/>
                        <w:lvlJc w:val="right"/>
                        <w:pPr>
                            <w:ind w:left="2520" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="6">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="decimal"/>
                        <w:lvlText w:val="%7."/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="2940" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="7">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerLetter"/>
                        <w:lvlText w:val="%8)"/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="3360" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="8">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerRoman"/>
                        <w:lvlText w:val="%9."/>
                        <w:lvlJc w:val="right"/>
                        <w:pPr>
                            <w:ind w:left="3780" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                </w:abstractNum>
                <w:abstractNum w:abstractNumId="7">
                    <w:nsid w:val="51BD0B4C"/>
                    <w:multiLevelType w:val="multilevel"/>
                    <w:tmpl w:val="51BD0B4C"/>
                    <w:lvl w:ilvl="0">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="decimal"/>
                        <w:lvlText w:val="%1."/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="0" w:firstLine="0"/>
                        </w:pPr>
                        <w:rPr>
                            <w:rFonts w:hint="eastAsia"/>
                        </w:rPr>
                    </w:lvl>
                    <w:lvl w:ilvl="1">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerLetter"/>
                        <w:lvlText w:val="%2)"/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="840" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="2">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerRoman"/>
                        <w:lvlText w:val="%3."/>
                        <w:lvlJc w:val="right"/>
                        <w:pPr>
                            <w:ind w:left="1260" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="3">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="decimal"/>
                        <w:lvlText w:val="%4."/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="1680" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="4">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerLetter"/>
                        <w:lvlText w:val="%5)"/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="2100" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="5">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerRoman"/>
                        <w:lvlText w:val="%6."/>
                        <w:lvlJc w:val="right"/>
                        <w:pPr>
                            <w:ind w:left="2520" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="6">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="decimal"/>
                        <w:lvlText w:val="%7."/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="2940" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="7">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerLetter"/>
                        <w:lvlText w:val="%8)"/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="3360" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="8">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerRoman"/>
                        <w:lvlText w:val="%9."/>
                        <w:lvlJc w:val="right"/>
                        <w:pPr>
                            <w:ind w:left="3780" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                </w:abstractNum>
                <w:abstractNum w:abstractNumId="8">
                    <w:nsid w:val="53360542"/>
                    <w:multiLevelType w:val="multilevel"/>
                    <w:tmpl w:val="53360542"/>
                    <w:lvl w:ilvl="0">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="japaneseCounting"/>
                        <w:lvlText w:val="%1、"/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="400" w:hanging="400"/>
                        </w:pPr>
                        <w:rPr>
                            <w:rFonts w:hint="default"/>
                        </w:rPr>
                    </w:lvl>
                    <w:lvl w:ilvl="1">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerLetter"/>
                        <w:lvlText w:val="%2)"/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="840" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="2">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerRoman"/>
                        <w:lvlText w:val="%3."/>
                        <w:lvlJc w:val="right"/>
                        <w:pPr>
                            <w:ind w:left="1260" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="3">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="decimal"/>
                        <w:lvlText w:val="%4."/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="1680" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="4">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerLetter"/>
                        <w:lvlText w:val="%5)"/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="2100" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="5">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerRoman"/>
                        <w:lvlText w:val="%6."/>
                        <w:lvlJc w:val="right"/>
                        <w:pPr>
                            <w:ind w:left="2520" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="6">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="decimal"/>
                        <w:lvlText w:val="%7."/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="2940" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="7">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerLetter"/>
                        <w:lvlText w:val="%8)"/>
                        <w:lvlJc w:val="left"/>
                        <w:pPr>
                            <w:ind w:left="3360" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                    <w:lvl w:ilvl="8">
                        <w:start w:val="1"/>
                        <w:numFmt w:val="lowerRoman"/>
                        <w:lvlText w:val="%9."/>
                        <w:lvlJc w:val="right"/>
                        <w:pPr>
                            <w:ind w:left="3780" w:hanging="420"/>
                        </w:pPr>
                    </w:lvl>
                </w:abstractNum>
                <w:abstractNum w:abstractNumId="9">
                    <w:nsid w:val="56FB8EB2"/>
                    <w:multiLevelType w:val="singleLevel"/>
                    <w:tmpl w:val="56FB8EB2"/>
                    <w:lvl w:ilvl="0">
                        <w:start w:val="2"/>
                        <w:numFmt w:val="decimal"/>
                        <w:suff w:val="nothing"/>
                        <w:lvlText w:val="%1、"/>
                        <w:lvlJc w:val="left"/>
                    </w:lvl>
                </w:abstractNum>
                <w:abstractNum w:abstractNumId="11">
					<w:nsid w:val="470D77CD"/>
					<w:multiLevelType w:val="hybridMultilevel"/>
					<w:tmpl w:val="79E02B3C"/>
					<w:lvl w:ilvl="0" w:tplc="0409000B">
						<w:start w:val="1"/>
						<w:numFmt w:val="bullet"/>
						<w:lvlText w:val=""/>
						<w:lvlJc w:val="left"/>
						<w:pPr>
							<w:ind w:left="420" w:hanging="420"/>
						</w:pPr>
						<w:rPr>
							<w:rFonts w:ascii="Wingdings" w:hAnsi="Wingdings" w:hint="default"/>
						</w:rPr>
					</w:lvl>
					<w:lvl w:ilvl="1" w:tplc="04090003" w:tentative="1">
						<w:start w:val="1"/>
						<w:numFmt w:val="bullet"/>
						<w:lvlText w:val=""/>
						<w:lvlJc w:val="left"/>
						<w:pPr>
							<w:ind w:left="840" w:hanging="420"/>
						</w:pPr>
						<w:rPr>
							<w:rFonts w:ascii="Wingdings" w:hAnsi="Wingdings" w:hint="default"/>
						</w:rPr>
					</w:lvl>
					<w:lvl w:ilvl="2" w:tplc="04090005" w:tentative="1">
						<w:start w:val="1"/>
						<w:numFmt w:val="bullet"/>
						<w:lvlText w:val=""/>
						<w:lvlJc w:val="left"/>
						<w:pPr>
							<w:ind w:left="1260" w:hanging="420"/>
						</w:pPr>
						<w:rPr>
							<w:rFonts w:ascii="Wingdings" w:hAnsi="Wingdings" w:hint="default"/>
						</w:rPr>
					</w:lvl>
					<w:lvl w:ilvl="3" w:tplc="04090001" w:tentative="1">
						<w:start w:val="1"/>
						<w:numFmt w:val="bullet"/>
						<w:lvlText w:val=""/>
						<w:lvlJc w:val="left"/>
						<w:pPr>
							<w:ind w:left="1680" w:hanging="420"/>
						</w:pPr>
						<w:rPr>
							<w:rFonts w:ascii="Wingdings" w:hAnsi="Wingdings" w:hint="default"/>
						</w:rPr>
					</w:lvl>
					<w:lvl w:ilvl="4" w:tplc="04090003" w:tentative="1">
						<w:start w:val="1"/>
						<w:numFmt w:val="bullet"/>
						<w:lvlText w:val=""/>
						<w:lvlJc w:val="left"/>
						<w:pPr>
							<w:ind w:left="2100" w:hanging="420"/>
						</w:pPr>
						<w:rPr>
							<w:rFonts w:ascii="Wingdings" w:hAnsi="Wingdings" w:hint="default"/>
						</w:rPr>
					</w:lvl>
					<w:lvl w:ilvl="5" w:tplc="04090005" w:tentative="1">
						<w:start w:val="1"/>
						<w:numFmt w:val="bullet"/>
						<w:lvlText w:val=""/>
						<w:lvlJc w:val="left"/>
						<w:pPr>
							<w:ind w:left="2520" w:hanging="420"/>
						</w:pPr>
						<w:rPr>
							<w:rFonts w:ascii="Wingdings" w:hAnsi="Wingdings" w:hint="default"/>
						</w:rPr>
					</w:lvl>
					<w:lvl w:ilvl="6" w:tplc="04090001" w:tentative="1">
						<w:start w:val="1"/>
						<w:numFmt w:val="bullet"/>
						<w:lvlText w:val=""/>
						<w:lvlJc w:val="left"/>
						<w:pPr>
							<w:ind w:left="2940" w:hanging="420"/>
						</w:pPr>
						<w:rPr>
							<w:rFonts w:ascii="Wingdings" w:hAnsi="Wingdings" w:hint="default"/>
						</w:rPr>
					</w:lvl>
					<w:lvl w:ilvl="7" w:tplc="04090003" w:tentative="1">
						<w:start w:val="1"/>
						<w:numFmt w:val="bullet"/>
						<w:lvlText w:val=""/>
						<w:lvlJc w:val="left"/>
						<w:pPr>
							<w:ind w:left="3360" w:hanging="420"/>
						</w:pPr>
						<w:rPr>
							<w:rFonts w:ascii="Wingdings" w:hAnsi="Wingdings" w:hint="default"/>
						</w:rPr>
					</w:lvl>
					<w:lvl w:ilvl="8" w:tplc="04090005" w:tentative="1">
						<w:start w:val="1"/>
						<w:numFmt w:val="bullet"/>
						<w:lvlText w:val=""/>
						<w:lvlJc w:val="left"/>
						<w:pPr>
							<w:ind w:left="3780" w:hanging="420"/>
						</w:pPr>
						<w:rPr>
							<w:rFonts w:ascii="Wingdings" w:hAnsi="Wingdings" w:hint="default"/>
						</w:rPr>
					</w:lvl>
				</w:abstractNum>
                <w:num w:numId="1">
                    <w:abstractNumId w:val="1"/>
                </w:num>
                <w:num w:numId="2">
                    <w:abstractNumId w:val="4"/>
                </w:num>
                <w:num w:numId="3">
                    <w:abstractNumId w:val="5"/>
                </w:num>
                <w:num w:numId="4">
                    <w:abstractNumId w:val="2"/>
                </w:num>
                <w:num w:numId="5">
                    <w:abstractNumId w:val="0"/>
                </w:num>
                <w:num w:numId="6">
                    <w:abstractNumId w:val="3"/>
                </w:num>
                <w:num w:numId="7">
                    <w:abstractNumId w:val="6"/>
                </w:num>
                <w:num w:numId="8">
                    <w:abstractNumId w:val="8"/>
                </w:num>
                <w:num w:numId="9">
                    <w:abstractNumId w:val="9"/>
                </w:num>
                <w:num w:numId="10">
                    <w:abstractNumId w:val="7"/>
                </w:num>
                <w:num w:numId="11">
                    <w:abstractNumId w:val="11"/>
                </w:num>
            </w:numbering>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/word/styles.xml" pkg:contentType="application/vnd.openxmlformats-officedocument.wordprocessingml.styles+xml">
        <pkg:xmlData>
            <w:styles mc:Ignorable="w14" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main" xmlns:w14="http://schemas.microsoft.com/office/word/2010/wordml">
                <w:docDefaults>
                    <w:rPrDefault>
                        <w:rPr>
                            <w:rFonts w:ascii="Times New Roman" w:eastAsia="宋体" w:hAnsi="Times New Roman" w:cs="Times New Roman"/>
                            <w:lang w:val="en-US" w:eastAsia="zh-CN" w:bidi="ar-SA"/>
                        </w:rPr>
                    </w:rPrDefault>
                    <w:pPrDefault/>
                </w:docDefaults>
                <w:latentStyles w:defLockedState="0" w:defUIPriority="99" w:defSemiHidden="0" w:defUnhideWhenUsed="1" w:defQFormat="0" w:count="267">
                    <w:lsdException w:name="Normal" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="heading 1" w:uiPriority="9" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="heading 2" w:uiPriority="9" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="heading 3" w:uiPriority="9" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="heading 4" w:locked="1" w:uiPriority="9" w:qFormat="1"/>
                    <w:lsdException w:name="heading 5" w:uiPriority="9" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="heading 6" w:locked="1" w:uiPriority="9" w:qFormat="1"/>
                    <w:lsdException w:name="heading 7" w:locked="1" w:uiPriority="9" w:qFormat="1"/>
                    <w:lsdException w:name="heading 8" w:locked="1" w:uiPriority="9" w:qFormat="1"/>
                    <w:lsdException w:name="heading 9" w:locked="1" w:uiPriority="9" w:qFormat="1"/>
                    <w:lsdException w:name="index 1" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 2" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 3" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 4" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 5" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 6" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 7" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 8" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 9" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="toc 1" w:uiPriority="39" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 2" w:uiPriority="39" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 3" w:uiPriority="39" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 4" w:locked="1" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 5" w:locked="1" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 6" w:locked="1" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 7" w:locked="1" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 8" w:locked="1" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 9" w:locked="1" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Normal Indent" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="footnote text" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="annotation text" w:qFormat="1"/>
                    <w:lsdException w:name="header" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="footer" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="index heading" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="caption" w:locked="1" w:uiPriority="35" w:qFormat="1"/>
                    <w:lsdException w:name="table of figures" w:semiHidden="1" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="envelope address" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="envelope return" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="footnote reference" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="annotation reference" w:qFormat="1"/>
                    <w:lsdException w:name="line number" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="page number" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="endnote reference" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="endnote text" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="table of authorities" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="macro" w:qFormat="1"/>
                    <w:lsdException w:name="toa heading" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List" w:qFormat="1"/>
                    <w:lsdException w:name="List Bullet" w:qFormat="1"/>
                    <w:lsdException w:name="List Number" w:qFormat="1"/>
                    <w:lsdException w:name="List 2" w:qFormat="1"/>
                    <w:lsdException w:name="List 3" w:qFormat="1"/>
                    <w:lsdException w:name="List 4" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List 5" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List Bullet 2" w:qFormat="1"/>
                    <w:lsdException w:name="List Bullet 3" w:qFormat="1"/>
                    <w:lsdException w:name="List Bullet 4" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List Bullet 5" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List Number 2" w:qFormat="1"/>
                    <w:lsdException w:name="List Number 3" w:qFormat="1"/>
                    <w:lsdException w:name="List Number 4" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List Number 5" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Title" w:locked="1" w:uiPriority="10" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Closing" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Signature" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Default Paragraph Font" w:semiHidden="1" w:uiPriority="1"/>
                    <w:lsdException w:name="Body Text" w:qFormat="1"/>
                    <w:lsdException w:name="Body Text Indent" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="List Continue" w:qFormat="1"/>
                    <w:lsdException w:name="List Continue 2" w:qFormat="1"/>
                    <w:lsdException w:name="List Continue 3" w:qFormat="1"/>
                    <w:lsdException w:name="List Continue 4" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List Continue 5" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Message Header" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Subtitle" w:locked="1" w:uiPriority="11" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Salutation" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Date" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Body Text First Indent" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Body Text First Indent 2" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Note Heading" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Body Text 2" w:qFormat="1"/>
                    <w:lsdException w:name="Body Text 3" w:qFormat="1"/>
                    <w:lsdException w:name="Body Text Indent 2" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Body Text Indent 3" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Block Text" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Hyperlink" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="FollowedHyperlink" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Strong" w:uiPriority="22" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Emphasis" w:uiPriority="20" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Document Map" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Plain Text" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="E-mail Signature" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Top of Form" w:semiHidden="1"/>
                    <w:lsdException w:name="HTML Bottom of Form" w:semiHidden="1"/>
                    <w:lsdException w:name="Normal (Web)" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="HTML Acronym" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Address" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Cite" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="HTML Code" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Definition" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Keyboard" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Preformatted" w:qFormat="1"/>
                    <w:lsdException w:name="HTML Sample" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Typewriter" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Variable" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Normal Table" w:semiHidden="1" w:qFormat="1"/>
                    <w:lsdException w:name="annotation subject" w:qFormat="1"/>
                    <w:lsdException w:name="No List" w:semiHidden="1"/>
                    <w:lsdException w:name="Outline List 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Outline List 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Outline List 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Simple 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Simple 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Simple 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Classic 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Classic 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Classic 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Classic 4" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Colorful 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Colorful 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Colorful 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Columns 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Columns 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Columns 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Columns 4" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Columns 5" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 4" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 5" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 6" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 7" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 8" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 4" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 5" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 6" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 7" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 8" w:semiHidden="1"/>
                    <w:lsdException w:name="Table 3D effects 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table 3D effects 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table 3D effects 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Contemporary" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Elegant" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Professional" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Subtle 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Subtle 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Web 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Web 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Web 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Balloon Text" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Table Grid" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Table Theme" w:semiHidden="1"/>
                    <w:lsdException w:name="Placeholder Text" w:semiHidden="1"/>
                    <w:lsdException w:name="No Spacing" w:semiHidden="1"/>
                    <w:lsdException w:name="Light Shading" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 2" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Shading Accent 1" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List Accent 1" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid Accent 1" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1 Accent 1" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2 Accent 1" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1 Accent 1" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Revision" w:semiHidden="1"/>
                    <w:lsdException w:name="List Paragraph" w:semiHidden="1"/>
                    <w:lsdException w:name="Quote" w:semiHidden="1"/>
                    <w:lsdException w:name="Intense Quote" w:semiHidden="1"/>
                    <w:lsdException w:name="Medium List 2 Accent 1" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1 Accent 1" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2 Accent 1" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3 Accent 1" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List Accent 1" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading Accent 1" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List Accent 1" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid Accent 1" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Shading Accent 2" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List Accent 2" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid Accent 2" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1 Accent 2" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2 Accent 2" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1 Accent 2" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 2 Accent 2" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1 Accent 2" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2 Accent 2" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3 Accent 2" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List Accent 2" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading Accent 2" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List Accent 2" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid Accent 2" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Shading Accent 3" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List Accent 3" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid Accent 3" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1 Accent 3" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2 Accent 3" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1 Accent 3" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 2 Accent 3" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1 Accent 3" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2 Accent 3" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3 Accent 3" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List Accent 3" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading Accent 3" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List Accent 3" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid Accent 3" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Shading Accent 4" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List Accent 4" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid Accent 4" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1 Accent 4" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2 Accent 4" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1 Accent 4" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 2 Accent 4" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1 Accent 4" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2 Accent 4" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3 Accent 4" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List Accent 4" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading Accent 4" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List Accent 4" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid Accent 4" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Shading Accent 5" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List Accent 5" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid Accent 5" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1 Accent 5" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2 Accent 5" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1 Accent 5" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 2 Accent 5" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1 Accent 5" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2 Accent 5" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3 Accent 5" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List Accent 5" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading Accent 5" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List Accent 5" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid Accent 5" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Shading Accent 6" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List Accent 6" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid Accent 6" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1 Accent 6" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2 Accent 6" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1 Accent 6" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 2 Accent 6" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1 Accent 6" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2 Accent 6" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3 Accent 6" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List Accent 6" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading Accent 6" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List Accent 6" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid Accent 6" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Subtle Emphasis" w:uiPriority="19" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Intense Emphasis" w:uiPriority="21" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Subtle Reference" w:uiPriority="31" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Intense Reference" w:uiPriority="32" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Book Title" w:uiPriority="33" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Bibliography" w:semiHidden="1" w:uiPriority="37"/>
                    <w:lsdException w:name="TOC Heading" w:semiHidden="1" w:uiPriority="39" w:qFormat="1"/>
                </w:latentStyles>
                <w:style w:type="paragraph" w:default="1" w:styleId="a1">
                    <w:name w:val="Normal"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl w:val="0"/>
                        <w:jc w:val="both"/>
                    </w:pPr>
                    <w:rPr>
                        <w:kern w:val="2"/>
                        <w:sz w:val="21"/>
                        <w:szCs w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="1">
                    <w:name w:val="heading 1"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="1Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:spacing w:line="578" w:lineRule="auto"/>
                        <w:jc w:val="center"/>
                        <w:outlineLvl w:val="0"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:kern w:val="44"/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="44"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="21">
                    <w:name w:val="heading 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="2Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:spacing w:before="260" w:after="260" w:line="416" w:lineRule="auto"/>
                        <w:outlineLvl w:val="1"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Arial" w:eastAsia="黑体" w:hAnsi="Arial"/>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="31">
                    <w:name w:val="heading 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="3Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:autoSpaceDE w:val="0"/>
                        <w:autoSpaceDN w:val="0"/>
                        <w:adjustRightInd w:val="0"/>
                        <w:spacing w:before="120" w:after="120" w:line="440" w:lineRule="exact"/>
                        <w:outlineLvl w:val="2"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体" w:cs="Tahoma"/>
                        <w:bCs/>
                        <w:color w:val="000000"/>
                        <w:sz w:val="28"/>
                        <w:szCs w:val="56"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="4">
                    <w:name w:val="heading 4"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="4Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:widowControl/>
                        <w:spacing w:before="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="3"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="5">
                    <w:name w:val="heading 5"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="5Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:spacing w:before="280" w:after="290" w:line="376" w:lineRule="auto"/>
                        <w:outlineLvl w:val="4"/>
                    </w:pPr>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="28"/>
                        <w:szCs w:val="28"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="6">
                    <w:name w:val="heading 6"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="6Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:widowControl/>
                        <w:spacing w:before="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="5"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="244061"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="7">
                    <w:name w:val="heading 7"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="7Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:widowControl/>
                        <w:spacing w:before="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="6"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="3F3F3F"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="8">
                    <w:name w:val="heading 8"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="8Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:widowControl/>
                        <w:spacing w:before="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="7"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:color w:val="4F81BD"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="20"/>
                        <w:szCs w:val="20"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="9">
                    <w:name w:val="heading 9"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="9Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:widowControl/>
                        <w:spacing w:before="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="8"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="3F3F3F"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="20"/>
                        <w:szCs w:val="20"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:default="1" w:styleId="a2">
                    <w:name w:val="Default Paragraph Font"/>
                    <w:uiPriority w:val="1"/>
                    <w:semiHidden/>
                    <w:unhideWhenUsed/>
                </w:style>
                <w:style w:type="table" w:default="1" w:styleId="a3">
                    <w:name w:val="Normal Table"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:unhideWhenUsed/>
                    <w:tblPr>
                        <w:tblInd w:w="0" w:type="dxa"/>
                        <w:tblCellMar>
                            <w:top w:w="0" w:type="dxa"/>
                            <w:left w:w="108" w:type="dxa"/>
                            <w:bottom w:w="0" w:type="dxa"/>
                            <w:right w:w="108" w:type="dxa"/>
                        </w:tblCellMar>
                    </w:tblPr>
                </w:style>
                <w:style w:type="numbering" w:default="1" w:styleId="a4">
                    <w:name w:val="No List"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:unhideWhenUsed/>
                </w:style>
                <w:style w:type="paragraph" w:styleId="32">
                    <w:name w:val="List 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="1080" w:hanging="360"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a5">
                    <w:name w:val="annotation subject"/>
                    <w:basedOn w:val="a6"/>
                    <w:next w:val="a6"/>
                    <w:link w:val="Char"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a6">
                    <w:name w:val="annotation text"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="Char0"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:jc w:val="left"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="70">
                    <w:name w:val="toc 7"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:ind w:leftChars="1200" w:left="2520"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="2">
                    <w:name w:val="List Number 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:numPr>
                            <w:numId w:val="1"/>
                        </w:numPr>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a7">
                    <w:name w:val="macro"/>
                    <w:link w:val="Char1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:tabs>
                            <w:tab w:val="left" w:pos="576"/>
                            <w:tab w:val="left" w:pos="1152"/>
                            <w:tab w:val="left" w:pos="1728"/>
                            <w:tab w:val="left" w:pos="2304"/>
                            <w:tab w:val="left" w:pos="2880"/>
                            <w:tab w:val="left" w:pos="3456"/>
                            <w:tab w:val="left" w:pos="4032"/>
                        </w:tabs>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Courier" w:hAnsi="Courier" w:cs="黑体"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a">
                    <w:name w:val="List Number"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:numPr>
                            <w:numId w:val="2"/>
                        </w:numPr>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a8">
                    <w:name w:val="caption"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="35"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="黑体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:sz w:val="20"/>
                        <w:szCs w:val="20"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a0">
                    <w:name w:val="List Bullet"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:numPr>
                            <w:numId w:val="3"/>
                        </w:numPr>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="33">
                    <w:name w:val="Body Text 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="3Char0"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="120" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="16"/>
                        <w:szCs w:val="16"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="30">
                    <w:name w:val="List Bullet 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:numPr>
                            <w:numId w:val="4"/>
                        </w:numPr>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a9">
                    <w:name w:val="Body Text"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="Char2"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="120" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="aa">
                    <w:name w:val="Body Text Indent"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="Char3"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:firstLineChars="200" w:firstLine="560"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="仿宋_GB2312" w:eastAsia="仿宋_GB2312"/>
                        <w:sz w:val="28"/>
                        <w:szCs w:val="28"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="3">
                    <w:name w:val="List Number 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:numPr>
                            <w:numId w:val="5"/>
                        </w:numPr>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="22">
                    <w:name w:val="List 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="720" w:hanging="360"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="ab">
                    <w:name w:val="List Continue"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="120" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="360"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="20">
                    <w:name w:val="List Bullet 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:numPr>
                            <w:numId w:val="6"/>
                        </w:numPr>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="50">
                    <w:name w:val="toc 5"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:ind w:leftChars="800" w:left="1680"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="34">
                    <w:name w:val="toc 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="39"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:leftChars="400" w:left="840"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="80">
                    <w:name w:val="toc 8"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:ind w:leftChars="1400" w:left="2940"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="ac">
                    <w:name w:val="Date"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="Char4"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:leftChars="2500" w:left="100"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="ad">
                    <w:name w:val="Balloon Text"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="Char5"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:sz w:val="18"/>
                        <w:szCs w:val="18"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="ae">
                    <w:name w:val="footer"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="Char6"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:tabs>
                            <w:tab w:val="center" w:pos="4153"/>
                            <w:tab w:val="right" w:pos="8306"/>
                        </w:tabs>
                        <w:snapToGrid w:val="0"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:sz w:val="18"/>
                        <w:szCs w:val="18"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="af">
                    <w:name w:val="header"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="Char7"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:pBdr>
                            <w:bottom w:val="single" w:sz="6" w:space="1" w:color="auto"/>
                        </w:pBdr>
                        <w:tabs>
                            <w:tab w:val="center" w:pos="4153"/>
                            <w:tab w:val="right" w:pos="8306"/>
                        </w:tabs>
                        <w:snapToGrid w:val="0"/>
                        <w:jc w:val="center"/>
                    </w:pPr>
                    <w:rPr>
                        <w:sz w:val="18"/>
                        <w:szCs w:val="18"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="10">
                    <w:name w:val="toc 1"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="39"/>
                    <w:qFormat/>
                </w:style>
                <w:style w:type="paragraph" w:styleId="40">
                    <w:name w:val="toc 4"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:ind w:leftChars="600" w:left="1260"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="af0">
                    <w:name w:val="Subtitle"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="Char8"/>
                    <w:uiPriority w:val="11"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                        <w:spacing w:val="15"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="24"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="af1">
                    <w:name w:val="List"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="360" w:hanging="360"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="60">
                    <w:name w:val="toc 6"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:ind w:leftChars="1000" w:left="2100"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="af2">
                    <w:name w:val="table of figures"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:line="440" w:lineRule="exact"/>
                        <w:ind w:leftChars="200" w:left="400" w:hangingChars="200" w:hanging="200"/>
                    </w:pPr>
                    <w:rPr>
                        <w:sz w:val="28"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="23">
                    <w:name w:val="toc 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="39"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:leftChars="200" w:left="420"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="90">
                    <w:name w:val="toc 9"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:ind w:leftChars="1600" w:left="3360"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="24">
                    <w:name w:val="Body Text 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="2Char0"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="120" w:line="480" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="25">
                    <w:name w:val="List Continue 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="120" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="720"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="HTML">
                    <w:name w:val="HTML Preformatted"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:tabs>
                            <w:tab w:val="left" w:pos="916"/>
                            <w:tab w:val="left" w:pos="1832"/>
                            <w:tab w:val="left" w:pos="2748"/>
                            <w:tab w:val="left" w:pos="3664"/>
                            <w:tab w:val="left" w:pos="4580"/>
                            <w:tab w:val="left" w:pos="5496"/>
                            <w:tab w:val="left" w:pos="6412"/>
                            <w:tab w:val="left" w:pos="7328"/>
                            <w:tab w:val="left" w:pos="8244"/>
                            <w:tab w:val="left" w:pos="9160"/>
                            <w:tab w:val="left" w:pos="10076"/>
                            <w:tab w:val="left" w:pos="10992"/>
                            <w:tab w:val="left" w:pos="11908"/>
                            <w:tab w:val="left" w:pos="12824"/>
                            <w:tab w:val="left" w:pos="13740"/>
                            <w:tab w:val="left" w:pos="14656"/>
                        </w:tabs>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="宋体" w:hAnsi="宋体" w:hint="eastAsia"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="af3">
                    <w:name w:val="Normal (Web)"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:before="100" w:beforeAutospacing="1" w:after="100" w:afterAutospacing="1"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="宋体" w:hAnsi="宋体" w:cs="宋体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="18"/>
                        <w:szCs w:val="18"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="35">
                    <w:name w:val="List Continue 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="120" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="1080"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="af4">
                    <w:name w:val="Title"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="Char9"/>
                    <w:uiPriority w:val="10"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:spacing w:before="240" w:after="60"/>
                        <w:jc w:val="center"/>
                        <w:outlineLvl w:val="0"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:styleId="af5">
                    <w:name w:val="Strong"/>
                    <w:uiPriority w:val="22"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:b/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:styleId="af6">
                    <w:name w:val="page number"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:styleId="af7">
                    <w:name w:val="Emphasis"/>
                    <w:uiPriority w:val="20"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:i/>
                        <w:shd w:val="clear" w:color="auto" w:fill="auto"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:styleId="af8">
                    <w:name w:val="Hyperlink"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:color w:val="0000FF"/>
                        <w:u w:val="single"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:styleId="af9">
                    <w:name w:val="annotation reference"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:sz w:val="21"/>
                        <w:szCs w:val="21"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:styleId="HTML0">
                    <w:name w:val="HTML Cite"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:sz w:val="20"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="00lk">
                    <w:name w:val="00lk 正文"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:line="360" w:lineRule="auto"/>
                        <w:ind w:firstLineChars="200" w:firstLine="640"/>
                        <w:jc w:val="both"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="p0">
                    <w:name w:val="p0"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                    </w:pPr>
                    <w:rPr>
                        <w:kern w:val="0"/>
                        <w:szCs w:val="21"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fymlw">
                    <w:name w:val="0fymlw正文"/>
                    <w:link w:val="0fymlwChar"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl w:val="0"/>
                        <w:spacing w:line="440" w:lineRule="exact"/>
                        <w:ind w:firstLineChars="200" w:firstLine="672"/>
                        <w:jc w:val="both"/>
                    </w:pPr>
                    <w:rPr>
                        <w:color w:val="000000"/>
                        <w:spacing w:val="8"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fym11">
                    <w:name w:val="0fym1.1"/>
                    <w:link w:val="0fym11Char"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:before="240" w:after="240" w:line="440" w:lineRule="exact"/>
                        <w:ind w:left="482" w:hanging="482"/>
                        <w:jc w:val="both"/>
                        <w:outlineLvl w:val="1"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:kern w:val="44"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fymlw0">
                    <w:name w:val="0fymlw摘要"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:beforeLines="50" w:afterLines="50" w:line="440" w:lineRule="exact"/>
                        <w:jc w:val="center"/>
                        <w:outlineLvl w:val="0"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:kern w:val="44"/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fym111">
                    <w:name w:val="0fym1.1.1"/>
                    <w:link w:val="0fym111Char"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:before="120" w:after="120" w:line="360" w:lineRule="auto"/>
                        <w:jc w:val="both"/>
                        <w:outlineLvl w:val="2"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:color w:val="000000"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fym1111">
                    <w:name w:val="0fym1.1.1.1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:before="120" w:after="120" w:line="440" w:lineRule="exact"/>
                        <w:jc w:val="both"/>
                        <w:outlineLvl w:val="3"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:bCs/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="24"/>
                        <w:szCs w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fym">
                    <w:name w:val="0fym第一章"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:snapToGrid w:val="0"/>
                        <w:spacing w:beforeLines="150" w:afterLines="150" w:line="440" w:lineRule="exact"/>
                        <w:jc w:val="center"/>
                        <w:outlineLvl w:val="0"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fym0">
                    <w:name w:val="0fym图"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:line="440" w:lineRule="exact"/>
                        <w:jc w:val="center"/>
                        <w:outlineLvl w:val="5"/>
                    </w:pPr>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="21"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fym1">
                    <w:name w:val="0fym表"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:line="440" w:lineRule="exact"/>
                        <w:jc w:val="center"/>
                    </w:pPr>
                    <w:rPr>
                        <w:bCs/>
                        <w:kern w:val="44"/>
                        <w:sz w:val="24"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="11">
                    <w:name w:val="正文1"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Verdana" w:hAnsi="Verdana" w:cs="宋体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="winfigtitle">
                    <w:name w:val="winfigtitle"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:before="100" w:beforeAutospacing="1" w:after="100" w:afterAutospacing="1"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="宋体" w:hAnsi="宋体" w:cs="宋体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="18"/>
                        <w:szCs w:val="18"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="12">
                    <w:name w:val="列出段落1"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="34"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:firstLineChars="200" w:firstLine="420"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri"/>
                        <w:szCs w:val="22"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fymEnglish">
                    <w:name w:val="0fym图English"/>
                    <w:basedOn w:val="0fym0"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="atl5">
                    <w:name w:val="atl5"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="宋体" w:hAnsi="宋体" w:cs="宋体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="17"/>
                        <w:szCs w:val="17"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="justify">
                    <w:name w:val="justify"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:before="100" w:beforeAutospacing="1" w:after="100" w:afterAutospacing="1"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="宋体" w:hAnsi="宋体" w:cs="宋体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="journal5">
                    <w:name w:val="journal5"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:line="456" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="宋体" w:hAnsi="宋体" w:cs="宋体"/>
                        <w:color w:val="7C7C7C"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="26"/>
                        <w:szCs w:val="26"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="13">
                    <w:name w:val="样式1"/>
                    <w:basedOn w:val="10"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:tabs>
                            <w:tab w:val="right" w:leader="dot" w:pos="8834"/>
                        </w:tabs>
                    </w:pPr>
                    <w:rPr>
                        <w:sz w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="26">
                    <w:name w:val="列出段落2"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:firstLineChars="200" w:firstLine="420"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri"/>
                        <w:szCs w:val="22"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="27">
                    <w:name w:val="样式2"/>
                    <w:basedOn w:val="1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="TOC1">
                    <w:name w:val="TOC 标题1"/>
                    <w:basedOn w:val="1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:before="480" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="9"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria"/>
                        <w:color w:val="365F91"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="28"/>
                        <w:szCs w:val="28"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="afa">
                    <w:name w:val="[基本段落]"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:autoSpaceDE w:val="0"/>
                        <w:autoSpaceDN w:val="0"/>
                        <w:adjustRightInd w:val="0"/>
                        <w:spacing w:line="288" w:lineRule="auto"/>
                        <w:textAlignment w:val="center"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Adobe 宋体 Std L" w:eastAsia="Adobe 宋体 Std L" w:cs="Adobe 宋体 Std L"/>
                        <w:color w:val="000000"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="24"/>
                        <w:lang w:val="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="14">
                    <w:name w:val="无间隔1"/>
                    <w:uiPriority w:val="1"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="15">
                    <w:name w:val="引用1"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="QuoteChar"/>
                    <w:uiPriority w:val="29"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="000000"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="16">
                    <w:name w:val="明显引用1"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="IntenseQuoteChar"/>
                    <w:uiPriority w:val="30"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:pBdr>
                            <w:bottom w:val="single" w:sz="4" w:space="4" w:color="4F81BD"/>
                        </w:pBdr>
                        <w:spacing w:before="200" w:after="280" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="936" w:right="936"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="TOC11">
                    <w:name w:val="TOC 标题11"/>
                    <w:basedOn w:val="1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="39"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:before="480" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="9"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:color w:val="365F90"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="28"/>
                        <w:szCs w:val="28"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="1Char">
                    <w:name w:val="标题 1 Char"/>
                    <w:link w:val="1"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:kern w:val="44"/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="44"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="2Char">
                    <w:name w:val="标题 2 Char"/>
                    <w:link w:val="21"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="Times New Roman"/>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="3Char">
                    <w:name w:val="标题 3 Char"/>
                    <w:link w:val="31"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体" w:cs="Times New Roman"/>
                        <w:color w:val="000000"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="56"/>
                        <w:lang w:val="en-US" w:eastAsia="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="4Char">
                    <w:name w:val="标题 4 Char"/>
                    <w:link w:val="4"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="5Char">
                    <w:name w:val="标题 5 Char"/>
                    <w:link w:val="5"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="28"/>
                        <w:szCs w:val="28"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="6Char">
                    <w:name w:val="标题 6 Char"/>
                    <w:link w:val="6"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="244061"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="7Char">
                    <w:name w:val="标题 7 Char"/>
                    <w:link w:val="7"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="3F3F3F"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="8Char">
                    <w:name w:val="标题 8 Char"/>
                    <w:link w:val="8"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:color w:val="4F81BD"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="20"/>
                        <w:szCs w:val="20"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="9Char">
                    <w:name w:val="标题 9 Char"/>
                    <w:link w:val="9"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="3F3F3F"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="20"/>
                        <w:szCs w:val="20"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="trans">
                    <w:name w:val="trans"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="0fymlwChar">
                    <w:name w:val="0fymlw正文 Char"/>
                    <w:link w:val="0fymlw"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:color w:val="000000"/>
                        <w:spacing w:val="8"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="22"/>
                        <w:lang w:val="en-US" w:eastAsia="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="0fym11Char">
                    <w:name w:val="0fym1.1 Char"/>
                    <w:link w:val="0fym11"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:kern w:val="44"/>
                        <w:sz w:val="22"/>
                        <w:lang w:val="en-US" w:eastAsia="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="0fym111Char">
                    <w:name w:val="0fym1.1.1 Char"/>
                    <w:link w:val="0fym111"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:color w:val="000000"/>
                        <w:sz w:val="22"/>
                        <w:lang w:val="en-US" w:eastAsia="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char7">
                    <w:name w:val="页眉 Char"/>
                    <w:link w:val="af"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:eastAsia="宋体" w:cs="Times New Roman"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="18"/>
                        <w:lang w:val="en-US" w:eastAsia="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char6">
                    <w:name w:val="页脚 Char"/>
                    <w:link w:val="ae"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:eastAsia="宋体" w:cs="Times New Roman"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="18"/>
                        <w:lang w:val="en-US" w:eastAsia="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="datatitle1">
                    <w:name w:val="datatitle1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                        <w:color w:val="10619F"/>
                        <w:sz w:val="23"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="normal1">
                    <w:name w:val="normal1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Verdana" w:hAnsi="Verdana"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char4">
                    <w:name w:val="日期 Char"/>
                    <w:link w:val="ac"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:sz w:val="24"/>
                        <w:szCs w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char3">
                    <w:name w:val="正文文本缩进 Char"/>
                    <w:link w:val="aa"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:sz w:val="24"/>
                        <w:szCs w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="word">
                    <w:name w:val="word"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="itatext">
                    <w:name w:val="itatext"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="brief2">
                    <w:name w:val="brief2"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:color w:val="444444"/>
                        <w:sz w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="citationjournal">
                    <w:name w:val="citation journal"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="peque1">
                    <w:name w:val="peque1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Verdana" w:hAnsi="Verdana"/>
                        <w:color w:val="423E3E"/>
                        <w:sz w:val="15"/>
                        <w:u w:val="none"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="apple-style-span">
                    <w:name w:val="apple-style-span"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="oblogtext">
                    <w:name w:val="oblog_text"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="listtext">
                    <w:name w:val="listtext"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="style1">
                    <w:name w:val="style1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="longtext1">
                    <w:name w:val="long_text1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:sz w:val="20"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="17">
                    <w:name w:val="日期1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="journalnumber">
                    <w:name w:val="journalnumber"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="journalname2">
                    <w:name w:val="journalname2"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:i/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="cite-pages">
                    <w:name w:val="cite-pages"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="cite-month-year">
                    <w:name w:val="cite-month-year"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="ttag">
                    <w:name w:val="t_tag"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="def3">
                    <w:name w:val="def3"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="collapsed-def4">
                    <w:name w:val="collapsed-def4"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:sz w:val="22"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char5">
                    <w:name w:val="批注框文本 Char"/>
                    <w:link w:val="ad"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="18"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="apple-converted-space">
                    <w:name w:val="apple-converted-space"/>
                    <w:basedOn w:val="a2"/>
                    <w:qFormat/>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char0">
                    <w:name w:val="批注文字 Char"/>
                    <w:link w:val="a6"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:szCs w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char">
                    <w:name w:val="批注主题 Char"/>
                    <w:link w:val="a5"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                        <w:szCs w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="18">
                    <w:name w:val="占位符文本1"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:color w:val="808080"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char9">
                    <w:name w:val="标题 Char"/>
                    <w:link w:val="af4"/>
                    <w:uiPriority w:val="10"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char1">
                    <w:name w:val="宏文本 Char"/>
                    <w:link w:val="a7"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Courier" w:eastAsia="宋体" w:hAnsi="Courier" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="20"/>
                        <w:szCs w:val="20"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="3Char0">
                    <w:name w:val="正文文本 3 Char"/>
                    <w:link w:val="33"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:eastAsia="宋体" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="16"/>
                        <w:szCs w:val="16"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char2">
                    <w:name w:val="正文文本 Char"/>
                    <w:link w:val="a9"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:eastAsia="宋体" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char8">
                    <w:name w:val="副标题 Char"/>
                    <w:link w:val="af0"/>
                    <w:uiPriority w:val="11"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                        <w:spacing w:val="15"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="24"/>
                        <w:szCs w:val="24"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="2Char0">
                    <w:name w:val="正文文本 2 Char"/>
                    <w:link w:val="24"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:eastAsia="宋体" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="QuoteChar">
                    <w:name w:val="Quote Char"/>
                    <w:link w:val="15"/>
                    <w:uiPriority w:val="29"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:eastAsia="宋体" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="000000"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="IntenseQuoteChar">
                    <w:name w:val="Intense Quote Char"/>
                    <w:link w:val="16"/>
                    <w:uiPriority w:val="30"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:eastAsia="宋体" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="19">
                    <w:name w:val="不明显强调1"/>
                    <w:uiPriority w:val="19"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="7C7C7C"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="1a">
                    <w:name w:val="明显强调1"/>
                    <w:uiPriority w:val="21"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="1b">
                    <w:name w:val="不明显参考1"/>
                    <w:uiPriority w:val="31"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:smallCaps/>
                        <w:color w:val="C0504D"/>
                        <w:u w:val="single"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="1c">
                    <w:name w:val="明显参考1"/>
                    <w:uiPriority w:val="32"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                        <w:smallCaps/>
                        <w:color w:val="C0504D"/>
                        <w:spacing w:val="5"/>
                        <w:u w:val="single"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="1d">
                    <w:name w:val="书籍标题1"/>
                    <w:uiPriority w:val="33"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                        <w:smallCaps/>
                        <w:spacing w:val="5"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="36">
                    <w:name w:val="列出段落3"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="34"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:firstLineChars="200" w:firstLine="420"/>
                    </w:pPr>
                </w:style>
            </w:styles>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/word/stylesWithEffects.xml" pkg:contentType="application/vnd.ms-word.stylesWithEffects+xml">
        <pkg:xmlData>
            <w:styles mc:Ignorable="w14 wp14" xmlns:wpc="http://schemas.microsoft.com/office/word/2010/wordprocessingCanvas" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" xmlns:o="urn:schemas-microsoft-com:office:office" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math" xmlns:v="urn:schemas-microsoft-com:vml" xmlns:wp14="http://schemas.microsoft.com/office/word/2010/wordprocessingDrawing" xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing" xmlns:w10="urn:schemas-microsoft-com:office:word" xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main" xmlns:w14="http://schemas.microsoft.com/office/word/2010/wordml" xmlns:wpg="http://schemas.microsoft.com/office/word/2010/wordprocessingGroup" xmlns:wpi="http://schemas.microsoft.com/office/word/2010/wordprocessingInk" xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml" xmlns:wps="http://schemas.microsoft.com/office/word/2010/wordprocessingShape">
                <w:docDefaults>
                    <w:rPrDefault>
                        <w:rPr>
                            <w:rFonts w:ascii="Times New Roman" w:eastAsia="宋体" w:hAnsi="Times New Roman" w:cs="Times New Roman"/>
                            <w:lang w:val="en-US" w:eastAsia="zh-CN" w:bidi="ar-SA"/>
                        </w:rPr>
                    </w:rPrDefault>
                    <w:pPrDefault/>
                </w:docDefaults>
                <w:latentStyles w:defLockedState="0" w:defUIPriority="99" w:defSemiHidden="0" w:defUnhideWhenUsed="1" w:defQFormat="0" w:count="267">
                    <w:lsdException w:name="Normal" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="heading 1" w:uiPriority="9" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="heading 2" w:uiPriority="9" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="heading 3" w:uiPriority="9" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="heading 4" w:locked="1" w:uiPriority="9" w:qFormat="1"/>
                    <w:lsdException w:name="heading 5" w:uiPriority="9" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="heading 6" w:locked="1" w:uiPriority="9" w:qFormat="1"/>
                    <w:lsdException w:name="heading 7" w:locked="1" w:uiPriority="9" w:qFormat="1"/>
                    <w:lsdException w:name="heading 8" w:locked="1" w:uiPriority="9" w:qFormat="1"/>
                    <w:lsdException w:name="heading 9" w:locked="1" w:uiPriority="9" w:qFormat="1"/>
                    <w:lsdException w:name="index 1" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 2" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 3" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 4" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 5" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 6" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 7" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 8" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="index 9" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="toc 1" w:uiPriority="39" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 2" w:uiPriority="39" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 3" w:uiPriority="39" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 4" w:locked="1" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 5" w:locked="1" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 6" w:locked="1" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 7" w:locked="1" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 8" w:locked="1" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="toc 9" w:locked="1" w:uiPriority="0" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Normal Indent" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="footnote text" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="annotation text" w:qFormat="1"/>
                    <w:lsdException w:name="header" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="footer" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="index heading" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="caption" w:locked="1" w:uiPriority="35" w:qFormat="1"/>
                    <w:lsdException w:name="table of figures" w:semiHidden="1" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="envelope address" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="envelope return" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="footnote reference" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="annotation reference" w:qFormat="1"/>
                    <w:lsdException w:name="line number" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="page number" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="endnote reference" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="endnote text" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="table of authorities" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="macro" w:qFormat="1"/>
                    <w:lsdException w:name="toa heading" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List" w:qFormat="1"/>
                    <w:lsdException w:name="List Bullet" w:qFormat="1"/>
                    <w:lsdException w:name="List Number" w:qFormat="1"/>
                    <w:lsdException w:name="List 2" w:qFormat="1"/>
                    <w:lsdException w:name="List 3" w:qFormat="1"/>
                    <w:lsdException w:name="List 4" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List 5" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List Bullet 2" w:qFormat="1"/>
                    <w:lsdException w:name="List Bullet 3" w:qFormat="1"/>
                    <w:lsdException w:name="List Bullet 4" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List Bullet 5" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List Number 2" w:qFormat="1"/>
                    <w:lsdException w:name="List Number 3" w:qFormat="1"/>
                    <w:lsdException w:name="List Number 4" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List Number 5" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Title" w:locked="1" w:uiPriority="10" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Closing" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Signature" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Default Paragraph Font" w:semiHidden="1" w:uiPriority="1"/>
                    <w:lsdException w:name="Body Text" w:qFormat="1"/>
                    <w:lsdException w:name="Body Text Indent" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="List Continue" w:qFormat="1"/>
                    <w:lsdException w:name="List Continue 2" w:qFormat="1"/>
                    <w:lsdException w:name="List Continue 3" w:qFormat="1"/>
                    <w:lsdException w:name="List Continue 4" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="List Continue 5" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Message Header" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Subtitle" w:locked="1" w:uiPriority="11" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Salutation" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Date" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Body Text First Indent" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Body Text First Indent 2" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Note Heading" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Body Text 2" w:qFormat="1"/>
                    <w:lsdException w:name="Body Text 3" w:qFormat="1"/>
                    <w:lsdException w:name="Body Text Indent 2" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Body Text Indent 3" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Block Text" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Hyperlink" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="FollowedHyperlink" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Strong" w:uiPriority="22" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Emphasis" w:uiPriority="20" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Document Map" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Plain Text" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="E-mail Signature" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Top of Form" w:semiHidden="1"/>
                    <w:lsdException w:name="HTML Bottom of Form" w:semiHidden="1"/>
                    <w:lsdException w:name="Normal (Web)" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="HTML Acronym" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Address" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Cite" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="HTML Code" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Definition" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Keyboard" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Preformatted" w:qFormat="1"/>
                    <w:lsdException w:name="HTML Sample" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Typewriter" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="HTML Variable" w:semiHidden="1" w:uiPriority="0"/>
                    <w:lsdException w:name="Normal Table" w:semiHidden="1" w:qFormat="1"/>
                    <w:lsdException w:name="annotation subject" w:qFormat="1"/>
                    <w:lsdException w:name="No List" w:semiHidden="1"/>
                    <w:lsdException w:name="Outline List 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Outline List 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Outline List 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Simple 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Simple 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Simple 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Classic 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Classic 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Classic 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Classic 4" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Colorful 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Colorful 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Colorful 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Columns 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Columns 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Columns 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Columns 4" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Columns 5" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 4" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 5" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 6" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 7" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Grid 8" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 4" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 5" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 6" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 7" w:semiHidden="1"/>
                    <w:lsdException w:name="Table List 8" w:semiHidden="1"/>
                    <w:lsdException w:name="Table 3D effects 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table 3D effects 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table 3D effects 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Contemporary" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Elegant" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Professional" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Subtle 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Subtle 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Web 1" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Web 2" w:semiHidden="1"/>
                    <w:lsdException w:name="Table Web 3" w:semiHidden="1"/>
                    <w:lsdException w:name="Balloon Text" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Table Grid" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Table Theme" w:semiHidden="1"/>
                    <w:lsdException w:name="Placeholder Text" w:semiHidden="1"/>
                    <w:lsdException w:name="No Spacing" w:semiHidden="1"/>
                    <w:lsdException w:name="Light Shading" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 2" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Shading Accent 1" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List Accent 1" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid Accent 1" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1 Accent 1" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2 Accent 1" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1 Accent 1" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Revision" w:semiHidden="1"/>
                    <w:lsdException w:name="List Paragraph" w:semiHidden="1"/>
                    <w:lsdException w:name="Quote" w:semiHidden="1"/>
                    <w:lsdException w:name="Intense Quote" w:semiHidden="1"/>
                    <w:lsdException w:name="Medium List 2 Accent 1" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1 Accent 1" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2 Accent 1" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3 Accent 1" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List Accent 1" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading Accent 1" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List Accent 1" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid Accent 1" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Shading Accent 2" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List Accent 2" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid Accent 2" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1 Accent 2" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2 Accent 2" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1 Accent 2" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 2 Accent 2" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1 Accent 2" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2 Accent 2" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3 Accent 2" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List Accent 2" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading Accent 2" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List Accent 2" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid Accent 2" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Shading Accent 3" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List Accent 3" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid Accent 3" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1 Accent 3" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2 Accent 3" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1 Accent 3" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 2 Accent 3" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1 Accent 3" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2 Accent 3" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3 Accent 3" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List Accent 3" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading Accent 3" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List Accent 3" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid Accent 3" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Shading Accent 4" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List Accent 4" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid Accent 4" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1 Accent 4" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2 Accent 4" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1 Accent 4" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 2 Accent 4" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1 Accent 4" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2 Accent 4" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3 Accent 4" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List Accent 4" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading Accent 4" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List Accent 4" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid Accent 4" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Shading Accent 5" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List Accent 5" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid Accent 5" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1 Accent 5" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2 Accent 5" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1 Accent 5" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 2 Accent 5" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1 Accent 5" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2 Accent 5" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3 Accent 5" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List Accent 5" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading Accent 5" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List Accent 5" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid Accent 5" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Shading Accent 6" w:uiPriority="60" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light List Accent 6" w:uiPriority="61" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Light Grid Accent 6" w:uiPriority="62" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 1 Accent 6" w:uiPriority="63" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Shading 2 Accent 6" w:uiPriority="64" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 1 Accent 6" w:uiPriority="65" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium List 2 Accent 6" w:uiPriority="66" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 1 Accent 6" w:uiPriority="67" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 2 Accent 6" w:uiPriority="68" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Medium Grid 3 Accent 6" w:uiPriority="69" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Dark List Accent 6" w:uiPriority="70" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Shading Accent 6" w:uiPriority="71" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful List Accent 6" w:uiPriority="72" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Colorful Grid Accent 6" w:uiPriority="73" w:unhideWhenUsed="0"/>
                    <w:lsdException w:name="Subtle Emphasis" w:uiPriority="19" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Intense Emphasis" w:uiPriority="21" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Subtle Reference" w:uiPriority="31" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Intense Reference" w:uiPriority="32" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Book Title" w:uiPriority="33" w:unhideWhenUsed="0" w:qFormat="1"/>
                    <w:lsdException w:name="Bibliography" w:semiHidden="1" w:uiPriority="37"/>
                    <w:lsdException w:name="TOC Heading" w:semiHidden="1" w:uiPriority="39" w:qFormat="1"/>
                </w:latentStyles>
                <w:style w:type="paragraph" w:default="1" w:styleId="a1">
                    <w:name w:val="Normal"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl w:val="0"/>
                        <w:jc w:val="both"/>
                    </w:pPr>
                    <w:rPr>
                        <w:kern w:val="2"/>
                        <w:sz w:val="21"/>
                        <w:szCs w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="1">
                    <w:name w:val="heading 1"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="1Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:spacing w:line="578" w:lineRule="auto"/>
                        <w:jc w:val="center"/>
                        <w:outlineLvl w:val="0"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:kern w:val="44"/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="44"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="21">
                    <w:name w:val="heading 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="2Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:spacing w:before="260" w:after="260" w:line="416" w:lineRule="auto"/>
                        <w:outlineLvl w:val="1"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Arial" w:eastAsia="黑体" w:hAnsi="Arial"/>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="31">
                    <w:name w:val="heading 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="3Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:autoSpaceDE w:val="0"/>
                        <w:autoSpaceDN w:val="0"/>
                        <w:adjustRightInd w:val="0"/>
                        <w:spacing w:before="120" w:after="120" w:line="440" w:lineRule="exact"/>
                        <w:outlineLvl w:val="2"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体" w:cs="Tahoma"/>
                        <w:bCs/>
                        <w:color w:val="000000"/>
                        <w:sz w:val="28"/>
                        <w:szCs w:val="56"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="4">
                    <w:name w:val="heading 4"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="4Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:widowControl/>
                        <w:spacing w:before="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="3"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="5">
                    <w:name w:val="heading 5"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="5Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:spacing w:before="280" w:after="290" w:line="376" w:lineRule="auto"/>
                        <w:outlineLvl w:val="4"/>
                    </w:pPr>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="28"/>
                        <w:szCs w:val="28"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="6">
                    <w:name w:val="heading 6"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="6Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:widowControl/>
                        <w:spacing w:before="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="5"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="244061"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="7">
                    <w:name w:val="heading 7"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="7Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:widowControl/>
                        <w:spacing w:before="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="6"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="3F3F3F"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="8">
                    <w:name w:val="heading 8"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="8Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:widowControl/>
                        <w:spacing w:before="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="7"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:color w:val="4F81BD"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="20"/>
                        <w:szCs w:val="20"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="9">
                    <w:name w:val="heading 9"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="9Char"/>
                    <w:uiPriority w:val="9"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:keepNext/>
                        <w:keepLines/>
                        <w:widowControl/>
                        <w:spacing w:before="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="8"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="3F3F3F"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="20"/>
                        <w:szCs w:val="20"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:default="1" w:styleId="a2">
                    <w:name w:val="Default Paragraph Font"/>
                    <w:uiPriority w:val="1"/>
                    <w:semiHidden/>
                    <w:unhideWhenUsed/>
                </w:style>
                <w:style w:type="table" w:default="1" w:styleId="a3">
                    <w:name w:val="Normal Table"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:unhideWhenUsed/>
                    <w:tblPr>
                        <w:tblInd w:w="0" w:type="dxa"/>
                        <w:tblCellMar>
                            <w:top w:w="0" w:type="dxa"/>
                            <w:left w:w="108" w:type="dxa"/>
                            <w:bottom w:w="0" w:type="dxa"/>
                            <w:right w:w="108" w:type="dxa"/>
                        </w:tblCellMar>
                    </w:tblPr>
                </w:style>
                <w:style w:type="numbering" w:default="1" w:styleId="a4">
                    <w:name w:val="No List"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:unhideWhenUsed/>
                </w:style>
                <w:style w:type="paragraph" w:styleId="32">
                    <w:name w:val="List 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="1080" w:hanging="360"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a5">
                    <w:name w:val="annotation subject"/>
                    <w:basedOn w:val="a6"/>
                    <w:next w:val="a6"/>
                    <w:link w:val="Char"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a6">
                    <w:name w:val="annotation text"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="Char0"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:jc w:val="left"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="70">
                    <w:name w:val="toc 7"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:ind w:leftChars="1200" w:left="2520"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="2">
                    <w:name w:val="List Number 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:numPr>
                            <w:numId w:val="1"/>
                        </w:numPr>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a7">
                    <w:name w:val="macro"/>
                    <w:link w:val="Char1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:tabs>
                            <w:tab w:val="left" w:pos="576"/>
                            <w:tab w:val="left" w:pos="1152"/>
                            <w:tab w:val="left" w:pos="1728"/>
                            <w:tab w:val="left" w:pos="2304"/>
                            <w:tab w:val="left" w:pos="2880"/>
                            <w:tab w:val="left" w:pos="3456"/>
                            <w:tab w:val="left" w:pos="4032"/>
                        </w:tabs>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Courier" w:hAnsi="Courier" w:cs="黑体"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a">
                    <w:name w:val="List Number"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:numPr>
                            <w:numId w:val="2"/>
                        </w:numPr>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a8">
                    <w:name w:val="caption"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="35"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="黑体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:sz w:val="20"/>
                        <w:szCs w:val="20"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a0">
                    <w:name w:val="List Bullet"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:numPr>
                            <w:numId w:val="3"/>
                        </w:numPr>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="33">
                    <w:name w:val="Body Text 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="3Char0"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="120" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="16"/>
                        <w:szCs w:val="16"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="30">
                    <w:name w:val="List Bullet 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:numPr>
                            <w:numId w:val="4"/>
                        </w:numPr>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="a9">
                    <w:name w:val="Body Text"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="Char2"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="120" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="aa">
                    <w:name w:val="Body Text Indent"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="Char3"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:firstLineChars="200" w:firstLine="560"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="仿宋_GB2312" w:eastAsia="仿宋_GB2312"/>
                        <w:sz w:val="28"/>
                        <w:szCs w:val="28"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="3">
                    <w:name w:val="List Number 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:numPr>
                            <w:numId w:val="5"/>
                        </w:numPr>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="22">
                    <w:name w:val="List 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="720" w:hanging="360"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="ab">
                    <w:name w:val="List Continue"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="120" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="360"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="20">
                    <w:name w:val="List Bullet 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:numPr>
                            <w:numId w:val="6"/>
                        </w:numPr>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="50">
                    <w:name w:val="toc 5"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:ind w:leftChars="800" w:left="1680"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="34">
                    <w:name w:val="toc 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="39"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:leftChars="400" w:left="840"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="80">
                    <w:name w:val="toc 8"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:ind w:leftChars="1400" w:left="2940"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="ac">
                    <w:name w:val="Date"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="Char4"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:leftChars="2500" w:left="100"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="ad">
                    <w:name w:val="Balloon Text"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="Char5"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:sz w:val="18"/>
                        <w:szCs w:val="18"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="ae">
                    <w:name w:val="footer"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="Char6"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:tabs>
                            <w:tab w:val="center" w:pos="4153"/>
                            <w:tab w:val="right" w:pos="8306"/>
                        </w:tabs>
                        <w:snapToGrid w:val="0"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:sz w:val="18"/>
                        <w:szCs w:val="18"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="af">
                    <w:name w:val="header"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="Char7"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:pBdr>
                            <w:bottom w:val="single" w:sz="6" w:space="1" w:color="auto"/>
                        </w:pBdr>
                        <w:tabs>
                            <w:tab w:val="center" w:pos="4153"/>
                            <w:tab w:val="right" w:pos="8306"/>
                        </w:tabs>
                        <w:snapToGrid w:val="0"/>
                        <w:jc w:val="center"/>
                    </w:pPr>
                    <w:rPr>
                        <w:sz w:val="18"/>
                        <w:szCs w:val="18"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="10">
                    <w:name w:val="toc 1"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="39"/>
                    <w:qFormat/>
                </w:style>
                <w:style w:type="paragraph" w:styleId="40">
                    <w:name w:val="toc 4"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:ind w:leftChars="600" w:left="1260"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="af0">
                    <w:name w:val="Subtitle"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="Char8"/>
                    <w:uiPriority w:val="11"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                        <w:spacing w:val="15"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="24"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="af1">
                    <w:name w:val="List"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="360" w:hanging="360"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="60">
                    <w:name w:val="toc 6"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:ind w:leftChars="1000" w:left="2100"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="af2">
                    <w:name w:val="table of figures"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:line="440" w:lineRule="exact"/>
                        <w:ind w:leftChars="200" w:left="400" w:hangingChars="200" w:hanging="200"/>
                    </w:pPr>
                    <w:rPr>
                        <w:sz w:val="28"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="23">
                    <w:name w:val="toc 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="39"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:leftChars="200" w:left="420"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="90">
                    <w:name w:val="toc 9"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:ind w:leftChars="1600" w:left="3360"/>
                    </w:pPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="24">
                    <w:name w:val="Body Text 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:link w:val="2Char0"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="120" w:line="480" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="25">
                    <w:name w:val="List Continue 2"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="120" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="720"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="HTML">
                    <w:name w:val="HTML Preformatted"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:tabs>
                            <w:tab w:val="left" w:pos="916"/>
                            <w:tab w:val="left" w:pos="1832"/>
                            <w:tab w:val="left" w:pos="2748"/>
                            <w:tab w:val="left" w:pos="3664"/>
                            <w:tab w:val="left" w:pos="4580"/>
                            <w:tab w:val="left" w:pos="5496"/>
                            <w:tab w:val="left" w:pos="6412"/>
                            <w:tab w:val="left" w:pos="7328"/>
                            <w:tab w:val="left" w:pos="8244"/>
                            <w:tab w:val="left" w:pos="9160"/>
                            <w:tab w:val="left" w:pos="10076"/>
                            <w:tab w:val="left" w:pos="10992"/>
                            <w:tab w:val="left" w:pos="11908"/>
                            <w:tab w:val="left" w:pos="12824"/>
                            <w:tab w:val="left" w:pos="13740"/>
                            <w:tab w:val="left" w:pos="14656"/>
                        </w:tabs>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="宋体" w:hAnsi="宋体" w:hint="eastAsia"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="af3">
                    <w:name w:val="Normal (Web)"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:before="100" w:beforeAutospacing="1" w:after="100" w:afterAutospacing="1"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="宋体" w:hAnsi="宋体" w:cs="宋体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="18"/>
                        <w:szCs w:val="18"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="35">
                    <w:name w:val="List Continue 3"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="120" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="1080"/>
                        <w:contextualSpacing/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:styleId="af4">
                    <w:name w:val="Title"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="Char9"/>
                    <w:uiPriority w:val="10"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:pPr>
                        <w:spacing w:before="240" w:after="60"/>
                        <w:jc w:val="center"/>
                        <w:outlineLvl w:val="0"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:styleId="af5">
                    <w:name w:val="Strong"/>
                    <w:uiPriority w:val="22"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:b/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:styleId="af6">
                    <w:name w:val="page number"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:styleId="af7">
                    <w:name w:val="Emphasis"/>
                    <w:uiPriority w:val="20"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:i/>
                        <w:shd w:val="clear" w:color="auto" w:fill="auto"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:styleId="af8">
                    <w:name w:val="Hyperlink"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:color w:val="0000FF"/>
                        <w:u w:val="single"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:styleId="af9">
                    <w:name w:val="annotation reference"/>
                    <w:uiPriority w:val="99"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:sz w:val="21"/>
                        <w:szCs w:val="21"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:styleId="HTML0">
                    <w:name w:val="HTML Cite"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:sz w:val="20"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="00lk">
                    <w:name w:val="00lk 正文"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:line="360" w:lineRule="auto"/>
                        <w:ind w:firstLineChars="200" w:firstLine="640"/>
                        <w:jc w:val="both"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="p0">
                    <w:name w:val="p0"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                    </w:pPr>
                    <w:rPr>
                        <w:kern w:val="0"/>
                        <w:szCs w:val="21"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fymlw">
                    <w:name w:val="0fymlw正文"/>
                    <w:link w:val="0fymlwChar"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl w:val="0"/>
                        <w:spacing w:line="440" w:lineRule="exact"/>
                        <w:ind w:firstLineChars="200" w:firstLine="672"/>
                        <w:jc w:val="both"/>
                    </w:pPr>
                    <w:rPr>
                        <w:color w:val="000000"/>
                        <w:spacing w:val="8"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fym11">
                    <w:name w:val="0fym1.1"/>
                    <w:link w:val="0fym11Char"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:before="240" w:after="240" w:line="440" w:lineRule="exact"/>
                        <w:ind w:left="482" w:hanging="482"/>
                        <w:jc w:val="both"/>
                        <w:outlineLvl w:val="1"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:kern w:val="44"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fymlw0">
                    <w:name w:val="0fymlw摘要"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:beforeLines="50" w:afterLines="50" w:line="440" w:lineRule="exact"/>
                        <w:jc w:val="center"/>
                        <w:outlineLvl w:val="0"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:kern w:val="44"/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fym111">
                    <w:name w:val="0fym1.1.1"/>
                    <w:link w:val="0fym111Char"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:before="120" w:after="120" w:line="360" w:lineRule="auto"/>
                        <w:jc w:val="both"/>
                        <w:outlineLvl w:val="2"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:color w:val="000000"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fym1111">
                    <w:name w:val="0fym1.1.1.1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:before="120" w:after="120" w:line="440" w:lineRule="exact"/>
                        <w:jc w:val="both"/>
                        <w:outlineLvl w:val="3"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:bCs/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="24"/>
                        <w:szCs w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fym">
                    <w:name w:val="0fym第一章"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:snapToGrid w:val="0"/>
                        <w:spacing w:beforeLines="150" w:afterLines="150" w:line="440" w:lineRule="exact"/>
                        <w:jc w:val="center"/>
                        <w:outlineLvl w:val="0"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fym0">
                    <w:name w:val="0fym图"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:line="440" w:lineRule="exact"/>
                        <w:jc w:val="center"/>
                        <w:outlineLvl w:val="5"/>
                    </w:pPr>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="21"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fym1">
                    <w:name w:val="0fym表"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:spacing w:line="440" w:lineRule="exact"/>
                        <w:jc w:val="center"/>
                    </w:pPr>
                    <w:rPr>
                        <w:bCs/>
                        <w:kern w:val="44"/>
                        <w:sz w:val="24"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="11">
                    <w:name w:val="正文1"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Verdana" w:hAnsi="Verdana" w:cs="宋体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="winfigtitle">
                    <w:name w:val="winfigtitle"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:before="100" w:beforeAutospacing="1" w:after="100" w:afterAutospacing="1"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="宋体" w:hAnsi="宋体" w:cs="宋体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="18"/>
                        <w:szCs w:val="18"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="12">
                    <w:name w:val="列出段落1"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="34"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:firstLineChars="200" w:firstLine="420"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri"/>
                        <w:szCs w:val="22"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="0fymEnglish">
                    <w:name w:val="0fym图English"/>
                    <w:basedOn w:val="0fym0"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="atl5">
                    <w:name w:val="atl5"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="宋体" w:hAnsi="宋体" w:cs="宋体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="17"/>
                        <w:szCs w:val="17"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="justify">
                    <w:name w:val="justify"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:before="100" w:beforeAutospacing="1" w:after="100" w:afterAutospacing="1"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="宋体" w:hAnsi="宋体" w:cs="宋体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="journal5">
                    <w:name w:val="journal5"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:line="456" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="宋体" w:hAnsi="宋体" w:cs="宋体"/>
                        <w:color w:val="7C7C7C"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="26"/>
                        <w:szCs w:val="26"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="13">
                    <w:name w:val="样式1"/>
                    <w:basedOn w:val="10"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:tabs>
                            <w:tab w:val="right" w:leader="dot" w:pos="8834"/>
                        </w:tabs>
                    </w:pPr>
                    <w:rPr>
                        <w:sz w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="26">
                    <w:name w:val="列出段落2"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:firstLineChars="200" w:firstLine="420"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri"/>
                        <w:szCs w:val="22"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="27">
                    <w:name w:val="样式2"/>
                    <w:basedOn w:val="1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="TOC1">
                    <w:name w:val="TOC 标题1"/>
                    <w:basedOn w:val="1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:before="480" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="9"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria"/>
                        <w:color w:val="365F91"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="28"/>
                        <w:szCs w:val="28"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="afa">
                    <w:name w:val="[基本段落]"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:autoSpaceDE w:val="0"/>
                        <w:autoSpaceDN w:val="0"/>
                        <w:adjustRightInd w:val="0"/>
                        <w:spacing w:line="288" w:lineRule="auto"/>
                        <w:textAlignment w:val="center"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Adobe 宋体 Std L" w:eastAsia="Adobe 宋体 Std L" w:cs="Adobe 宋体 Std L"/>
                        <w:color w:val="000000"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="24"/>
                        <w:lang w:val="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="14">
                    <w:name w:val="无间隔1"/>
                    <w:uiPriority w:val="1"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="15">
                    <w:name w:val="引用1"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="QuoteChar"/>
                    <w:uiPriority w:val="29"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:after="200" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="000000"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="16">
                    <w:name w:val="明显引用1"/>
                    <w:basedOn w:val="a1"/>
                    <w:next w:val="a1"/>
                    <w:link w:val="IntenseQuoteChar"/>
                    <w:uiPriority w:val="30"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:pBdr>
                            <w:bottom w:val="single" w:sz="4" w:space="4" w:color="4F81BD"/>
                        </w:pBdr>
                        <w:spacing w:before="200" w:after="280" w:line="276" w:lineRule="auto"/>
                        <w:ind w:left="936" w:right="936"/>
                        <w:jc w:val="left"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:szCs w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="TOC11">
                    <w:name w:val="TOC 标题11"/>
                    <w:basedOn w:val="1"/>
                    <w:next w:val="a1"/>
                    <w:uiPriority w:val="39"/>
                    <w:unhideWhenUsed/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:widowControl/>
                        <w:spacing w:before="480" w:line="276" w:lineRule="auto"/>
                        <w:jc w:val="left"/>
                        <w:outlineLvl w:val="9"/>
                    </w:pPr>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:color w:val="365F90"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="28"/>
                        <w:szCs w:val="28"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="1Char">
                    <w:name w:val="标题 1 Char"/>
                    <w:link w:val="1"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:kern w:val="44"/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="44"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="2Char">
                    <w:name w:val="标题 2 Char"/>
                    <w:link w:val="21"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="Times New Roman"/>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="3Char">
                    <w:name w:val="标题 3 Char"/>
                    <w:link w:val="31"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体" w:cs="Times New Roman"/>
                        <w:color w:val="000000"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="56"/>
                        <w:lang w:val="en-US" w:eastAsia="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="4Char">
                    <w:name w:val="标题 4 Char"/>
                    <w:link w:val="4"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="5Char">
                    <w:name w:val="标题 5 Char"/>
                    <w:link w:val="5"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="28"/>
                        <w:szCs w:val="28"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="6Char">
                    <w:name w:val="标题 6 Char"/>
                    <w:link w:val="6"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="244061"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="7Char">
                    <w:name w:val="标题 7 Char"/>
                    <w:link w:val="7"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="3F3F3F"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="8Char">
                    <w:name w:val="标题 8 Char"/>
                    <w:link w:val="8"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:color w:val="4F81BD"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="20"/>
                        <w:szCs w:val="20"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="9Char">
                    <w:name w:val="标题 9 Char"/>
                    <w:link w:val="9"/>
                    <w:uiPriority w:val="9"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="3F3F3F"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="20"/>
                        <w:szCs w:val="20"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="trans">
                    <w:name w:val="trans"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="0fymlwChar">
                    <w:name w:val="0fymlw正文 Char"/>
                    <w:link w:val="0fymlw"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:color w:val="000000"/>
                        <w:spacing w:val="8"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="22"/>
                        <w:lang w:val="en-US" w:eastAsia="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="0fym11Char">
                    <w:name w:val="0fym1.1 Char"/>
                    <w:link w:val="0fym11"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:kern w:val="44"/>
                        <w:sz w:val="22"/>
                        <w:lang w:val="en-US" w:eastAsia="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="0fym111Char">
                    <w:name w:val="0fym1.1.1 Char"/>
                    <w:link w:val="0fym111"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:eastAsia="黑体"/>
                        <w:color w:val="000000"/>
                        <w:sz w:val="22"/>
                        <w:lang w:val="en-US" w:eastAsia="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char7">
                    <w:name w:val="页眉 Char"/>
                    <w:link w:val="af"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:eastAsia="宋体" w:cs="Times New Roman"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="18"/>
                        <w:lang w:val="en-US" w:eastAsia="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char6">
                    <w:name w:val="页脚 Char"/>
                    <w:link w:val="ae"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:eastAsia="宋体" w:cs="Times New Roman"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="18"/>
                        <w:lang w:val="en-US" w:eastAsia="zh-CN"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="datatitle1">
                    <w:name w:val="datatitle1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                        <w:color w:val="10619F"/>
                        <w:sz w:val="23"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="normal1">
                    <w:name w:val="normal1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Verdana" w:hAnsi="Verdana"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char4">
                    <w:name w:val="日期 Char"/>
                    <w:link w:val="ac"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:sz w:val="24"/>
                        <w:szCs w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char3">
                    <w:name w:val="正文文本缩进 Char"/>
                    <w:link w:val="aa"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:sz w:val="24"/>
                        <w:szCs w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="word">
                    <w:name w:val="word"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="itatext">
                    <w:name w:val="itatext"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="brief2">
                    <w:name w:val="brief2"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:color w:val="444444"/>
                        <w:sz w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="citationjournal">
                    <w:name w:val="citation journal"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="peque1">
                    <w:name w:val="peque1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Verdana" w:hAnsi="Verdana"/>
                        <w:color w:val="423E3E"/>
                        <w:sz w:val="15"/>
                        <w:u w:val="none"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="apple-style-span">
                    <w:name w:val="apple-style-span"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="oblogtext">
                    <w:name w:val="oblog_text"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="listtext">
                    <w:name w:val="listtext"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="style1">
                    <w:name w:val="style1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="longtext1">
                    <w:name w:val="long_text1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:sz w:val="20"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="17">
                    <w:name w:val="日期1"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="journalnumber">
                    <w:name w:val="journalnumber"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="journalname2">
                    <w:name w:val="journalname2"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:i/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="cite-pages">
                    <w:name w:val="cite-pages"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="cite-month-year">
                    <w:name w:val="cite-month-year"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="ttag">
                    <w:name w:val="t_tag"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="def3">
                    <w:name w:val="def3"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="collapsed-def4">
                    <w:name w:val="collapsed-def4"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:sz w:val="22"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char5">
                    <w:name w:val="批注框文本 Char"/>
                    <w:link w:val="ad"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:locked/>
                    <w:rPr>
                        <w:rFonts w:cs="Times New Roman"/>
                        <w:kern w:val="2"/>
                        <w:sz w:val="18"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="apple-converted-space">
                    <w:name w:val="apple-converted-space"/>
                    <w:basedOn w:val="a2"/>
                    <w:qFormat/>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char0">
                    <w:name w:val="批注文字 Char"/>
                    <w:link w:val="a6"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:szCs w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char">
                    <w:name w:val="批注主题 Char"/>
                    <w:link w:val="a5"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                        <w:szCs w:val="24"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="18">
                    <w:name w:val="占位符文本1"/>
                    <w:uiPriority w:val="99"/>
                    <w:semiHidden/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:color w:val="808080"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char9">
                    <w:name w:val="标题 Char"/>
                    <w:link w:val="af4"/>
                    <w:uiPriority w:val="10"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:sz w:val="32"/>
                        <w:szCs w:val="32"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char1">
                    <w:name w:val="宏文本 Char"/>
                    <w:link w:val="a7"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Courier" w:eastAsia="宋体" w:hAnsi="Courier" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="20"/>
                        <w:szCs w:val="20"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="3Char0">
                    <w:name w:val="正文文本 3 Char"/>
                    <w:link w:val="33"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:eastAsia="宋体" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="16"/>
                        <w:szCs w:val="16"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char2">
                    <w:name w:val="正文文本 Char"/>
                    <w:link w:val="a9"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:eastAsia="宋体" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="Char8">
                    <w:name w:val="副标题 Char"/>
                    <w:link w:val="af0"/>
                    <w:uiPriority w:val="11"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Cambria" w:eastAsia="宋体" w:hAnsi="Cambria" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                        <w:spacing w:val="15"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="24"/>
                        <w:szCs w:val="24"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="2Char0">
                    <w:name w:val="正文文本 2 Char"/>
                    <w:link w:val="24"/>
                    <w:uiPriority w:val="99"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:eastAsia="宋体" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="QuoteChar">
                    <w:name w:val="Quote Char"/>
                    <w:link w:val="15"/>
                    <w:uiPriority w:val="29"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:eastAsia="宋体" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="000000"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="IntenseQuoteChar">
                    <w:name w:val="Intense Quote Char"/>
                    <w:link w:val="16"/>
                    <w:uiPriority w:val="30"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:rFonts w:ascii="Calibri" w:eastAsia="宋体" w:hAnsi="Calibri" w:cs="黑体"/>
                        <w:b/>
                        <w:bCs/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                        <w:kern w:val="0"/>
                        <w:sz w:val="22"/>
                        <w:lang w:eastAsia="en-US"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="19">
                    <w:name w:val="不明显强调1"/>
                    <w:uiPriority w:val="19"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="7C7C7C"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="1a">
                    <w:name w:val="明显强调1"/>
                    <w:uiPriority w:val="21"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                        <w:i/>
                        <w:iCs/>
                        <w:color w:val="4F81BD"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="1b">
                    <w:name w:val="不明显参考1"/>
                    <w:uiPriority w:val="31"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:smallCaps/>
                        <w:color w:val="C0504D"/>
                        <w:u w:val="single"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="1c">
                    <w:name w:val="明显参考1"/>
                    <w:uiPriority w:val="32"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                        <w:smallCaps/>
                        <w:color w:val="C0504D"/>
                        <w:spacing w:val="5"/>
                        <w:u w:val="single"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="character" w:customStyle="1" w:styleId="1d">
                    <w:name w:val="书籍标题1"/>
                    <w:uiPriority w:val="33"/>
                    <w:qFormat/>
                    <w:rPr>
                        <w:b/>
                        <w:bCs/>
                        <w:smallCaps/>
                        <w:spacing w:val="5"/>
                    </w:rPr>
                </w:style>
                <w:style w:type="paragraph" w:customStyle="1" w:styleId="36">
                    <w:name w:val="列出段落3"/>
                    <w:basedOn w:val="a1"/>
                    <w:uiPriority w:val="34"/>
                    <w:qFormat/>
                    <w:pPr>
                        <w:ind w:firstLineChars="200" w:firstLine="420"/>
                    </w:pPr>
                </w:style>
            </w:styles>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/word/webSettings.xml" pkg:contentType="application/vnd.openxmlformats-officedocument.wordprocessingml.webSettings+xml">
        <pkg:xmlData>
            <w:webSettings mc:Ignorable="w14" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main" xmlns:w14="http://schemas.microsoft.com/office/word/2010/wordml"/>
        </pkg:xmlData>
    </pkg:part>
    <pkg:part pkg:name="/docProps/core.xml" pkg:contentType="application/vnd.openxmlformats-package.core-properties+xml" pkg:padding="256">
        <pkg:xmlData>
            <cp:coreProperties xmlns:cp="http://schemas.openxmlformats.org/package/2006/metadata/core-properties" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:dcterms="http://purl.org/dc/terms/" xmlns:dcmitype="http://purl.org/dc/dcmitype/" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
                <dc:title>摘要</dc:title>
                <dc:creator>f</dc:creator>
                <cp:lastModifiedBy>wubo</cp:lastModifiedBy>
                <cp:revision>2</cp:revision>
                <cp:lastPrinted>2016-03-24T06:02:00Z</cp:lastPrinted>
                <dcterms:created xsi:type="dcterms:W3CDTF">2016-11-15T03:22:00Z</dcterms:created>
                <dcterms:modified xsi:type="dcterms:W3CDTF">2016-11-15T03:22:00Z</dcterms:modified>
            </cp:coreProperties>
        </pkg:xmlData>
    </pkg:part>
</pkg:package>'''
if __name__ == "__main__":
    pass
    

